from _typeshed import Incomplete

import _win32typing

def HrInstallService() -> None: ...
def HrInstallMailboxAgent() -> None: ...
def HrCreateMailboxAgentProfile(serviceName: str, profile: str) -> None: ...
def HrCreateGatewayProfile(serviceName: str, profile: str) -> None: ...
def HrMailboxAgentExists(server: str, siteDN: str, rdn: str) -> None: ...
def HrAdminProgramExists() -> None: ...
def HrRemoveMailboxAgent(server: str, siteDN: str, rdn: str) -> None: ...
def HrRemoveProfile(profile: str) -> None: ...
def HrEnumOrganizations(rootDN: str, server: str) -> list[str]: ...
def HrEnumSites(server: str, organizationDN: str) -> list[str]: ...
def HrEnumContainers(server: str, siteDN: str, fSubtree) -> list[str]: ...
def HrEnumSiteAdmins(server: str, siteDN: str) -> list[str]: ...
def HrGetServiceAccountName(serviceName: str, serviceName1: str) -> str: ...
def HrCreateDirEntryIdEx(addrBook: _win32typing.PyIAddrBook, distinguishedName: str) -> str: ...
def HrCreateProfileName(profPrefix: str) -> str: ...
def HrFindExchangeGlobalAddresslist(addrBook: _win32typing.PyIAddrBook) -> str: ...
def HrGetExchangeStatus(server: str) -> tuple[Incomplete, Incomplete]: ...
def HrGetMailboxDN(session) -> str: ...
def HrGetServerDN(session) -> str: ...
def HrMAPIFindDefaultMsgStore(session: _win32typing.PyIMAPISession) -> str: ...
def HrMAPIFindFolder(folder: _win32typing.PyIMAPIFolder, name: str) -> str: ...
def HrMAPIFindFolderEx(msgStore: _win32typing.PyIMsgStore, sepString: str, path: str) -> str: ...
def HrMAPIFindIPMSubtree(msgStore: _win32typing.PyIMsgStore) -> str: ...
def HrMAPIFindInbox(msgStore: _win32typing.PyIMsgStore) -> str: ...
def HrMAPIFindStore(session: _win32typing.PyIMAPISession, name: str) -> _win32typing.PyIMsgStore: ...
def HrMAPIFindSubfolderEx(rootFolder: _win32typing.PyIMAPIFolder, sep: str, name: str) -> _win32typing.PyIMsgStore: ...
def HrMAPIOpenFolderEx(msgStore: _win32typing.PyIMsgStore, sep: str, name: str) -> _win32typing.PyIMAPIFolder: ...
def HrMAPISetPropBoolean(obj: _win32typing.PyIMAPIProp, tag) -> None: ...
def HrMAPISetPropLong(obj: _win32typing.PyIMAPIProp, tag) -> None: ...
def HrMailboxLogoff(inbox: _win32typing.PyIMsgStore) -> None: ...
def HrMailboxLogon(
    session: _win32typing.PyIMAPISession, msgStore: _win32typing.PyIMsgStore, msgStoreDN: str, mailboxDN: str
) -> _win32typing.PyIMsgStore: ...
def HrOpenExchangePrivateStore(session: _win32typing.PyIMAPISession) -> _win32typing.PyIMsgStore: ...
def HrOpenExchangePublicFolders(store: _win32typing.PyIMsgStore) -> _win32typing.PyIMAPIFolder: ...
def HrOpenExchangePublicStore(session: _win32typing.PyIMAPISession) -> _win32typing.PyIMsgStore: ...
def HrOpenSessionObject(session: _win32typing.PyIMAPISession) -> _win32typing.PyIMAPIProp: ...
def HrOpenSiteContainer(session: _win32typing.PyIMAPISession) -> _win32typing.PyIMAPIProp: ...
def HrOpenSiteContainerAddressing(session: _win32typing.PyIMAPISession) -> _win32typing.PyIMAPIProp: ...



from _typeshed import Incomplete

PSGUID_STORAGE: Incomplete
PSGUID_SUMMARYINFORMATION: Incomplete
PSGUID_HTMLINFORMATION: Incomplete
PSGUID_HTML2_INFORMATION: Incomplete
IFILTER_INIT_CANON_PARAGRAPHS: int
IFILTER_INIT_HARD_LINE_BREAKS: int
IFILTER_INIT_CANON_HYPHENS: int
IFILTER_INIT_CANON_SPACES: int
IFILTER_INIT_APPLY_INDEX_ATTRIBUTES: int
IFILTER_INIT_APPLY_CRAWL_ATTRIBUTES: int
IFILTER_INIT_APPLY_OTHER_ATTRIBUTES: int
IFILTER_INIT_INDEXING_ONLY: int
IFILTER_INIT_SEARCH_LINKS: int
IFILTER_INIT_FILTER_OWNED_VALUE_OK: int
IFILTER_FLAGS_OLE_PROPERTIES: int
CHUNK_TEXT: int
CHUNK_VALUE: int
CHUNK_NO_BREAK: int
CHUNK_EOW: int
CHUNK_EOS: int
CHUNK_EOP: int
CHUNK_EOC: int
NOT_AN_ERROR: int
FILTER_E_END_OF_CHUNKS: int
FILTER_E_NO_MORE_TEXT: int
FILTER_E_NO_MORE_VALUES: int
FILTER_E_ACCESS: int
FILTER_W_MONIKER_CLIPPED: int
FILTER_E_NO_TEXT: int
FILTER_E_NO_VALUES: int
FILTER_E_EMBEDDING_UNAVAILABLE: int
FILTER_E_LINK_UNAVAILABLE: int
FILTER_S_LAST_TEXT: int
FILTER_S_LAST_VALUES: int
FILTER_E_PASSWORD: int
FILTER_E_UNKNOWNFORMAT: int
PROPSETFLAG_DEFAULT: int
PROPSETFLAG_NONSIMPLE: int
PROPSETFLAG_ANSI: int
PROPSETFLAG_UNBUFFERED: int
PROPSETFLAG_CASE_SENSITIVE: int
PROPSET_BEHAVIOR_CASE_SENSITIVE: int
PID_DICTIONARY: int
PID_CODEPAGE: int
PID_FIRST_USABLE: int
PID_FIRST_NAME_DEFAULT: int
PID_LOCALE: int
PID_MODIFY_TIME: int
PID_SECURITY: int
PID_BEHAVIOR: int
PID_ILLEGAL: int
PID_MIN_READONLY: int
PID_MAX_READONLY: int
PIDDI_THUMBNAIL: int
PIDSI_TITLE: int
PIDSI_SUBJECT: int
PIDSI_AUTHOR: int
PIDSI_KEYWORDS: int
PIDSI_COMMENTS: int
PIDSI_TEMPLATE: int
PIDSI_LASTAUTHOR: int
PIDSI_REVNUMBER: int
PIDSI_EDITTIME: int
PIDSI_LASTPRINTED: int
PIDSI_CREATE_DTM: int
PIDSI_LASTSAVE_DTM: int
PIDSI_PAGECOUNT: int
PIDSI_WORDCOUNT: int
PIDSI_CHARCOUNT: int
PIDSI_THUMBNAIL: int
PIDSI_APPNAME: int
PIDSI_DOC_SECURITY: int
PIDDSI_CATEGORY: int
PIDDSI_PRESFORMAT: int
PIDDSI_BYTECOUNT: int
PIDDSI_LINECOUNT: int
PIDDSI_PARCOUNT: int
PIDDSI_SLIDECOUNT: int
PIDDSI_NOTECOUNT: int
PIDDSI_HIDDENCOUNT: int
PIDDSI_MMCLIPCOUNT: int
PIDDSI_SCALE: int
PIDDSI_HEADINGPAIR: int
PIDDSI_DOCPARTS: int
PIDDSI_MANAGER: int
PIDDSI_COMPANY: int
PIDDSI_LINKSDIRTY: int
PIDMSI_EDITOR: int
PIDMSI_SUPPLIER: int
PIDMSI_SOURCE: int
PIDMSI_SEQUENCE_NO: int
PIDMSI_PROJECT: int
PIDMSI_STATUS: int
PIDMSI_OWNER: int
PIDMSI_RATING: int
PIDMSI_PRODUCTION: int
PIDMSI_COPYRIGHT: int
PRSPEC_INVALID: int
PRSPEC_LPWSTR: int
PRSPEC_PROPID: int
CCH_MAX_PROPSTG_NAME: int



from _typeshed import Incomplete

import _win32typing

def DirectSoundCreate(guid: _win32typing.PyIID | None = ..., unk: Incomplete | None = ...) -> _win32typing.PyIUnknown: ...
def DirectSoundEnumerate(): ...
def DirectSoundCaptureCreate(guid: _win32typing.PyIID | None = ..., unk: Incomplete | None = ...) -> _win32typing.PyIUnknown: ...
def DirectSoundCaptureEnumerate(): ...
def DSCAPS() -> _win32typing.PyDSCAPS: ...
def DSBCAPS() -> _win32typing.PyDSBCAPS: ...
def DSCCAPS() -> _win32typing.PyDSCCAPS: ...
def DSCBCAPS() -> _win32typing.PyDSCBCAPS: ...
def DSBUFFERDESC() -> _win32typing.PyDSBUFFERDESC: ...
def DSCBUFFERDESC() -> _win32typing.PyDSCBUFFERDESC: ...

DS3DMODE_DISABLE: int
DS3DMODE_HEADRELATIVE: int
DS3DMODE_NORMAL: int
DSBCAPS_CTRL3D: int
DSBCAPS_CTRLFREQUENCY: int
DSBCAPS_CTRLPAN: int
DSBCAPS_CTRLPOSITIONNOTIFY: int
DSBCAPS_CTRLVOLUME: int
DSBCAPS_GETCURRENTPOSITION2: int
DSBCAPS_GLOBALFOCUS: int
DSBCAPS_LOCHARDWARE: int
DSBCAPS_LOCSOFTWARE: int
DSBCAPS_MUTE3DATMAXDISTANCE: int
DSBCAPS_PRIMARYBUFFER: int
DSBCAPS_STATIC: int
DSBCAPS_STICKYFOCUS: int
DSBLOCK_ENTIREBUFFER: int
DSBLOCK_FROMWRITECURSOR: int
DSBPLAY_LOOPING: int
DSBSTATUS_BUFFERLOST: int
DSBSTATUS_LOOPING: int
DSBSTATUS_PLAYING: int
DSCAPS_CERTIFIED: int
DSCAPS_CONTINUOUSRATE: int
DSCAPS_EMULDRIVER: int
DSCAPS_PRIMARY16BIT: int
DSCAPS_PRIMARY8BIT: int
DSCAPS_PRIMARYMONO: int
DSCAPS_PRIMARYSTEREO: int
DSCAPS_SECONDARY16BIT: int
DSCAPS_SECONDARY8BIT: int
DSCAPS_SECONDARYMONO: int
DSCAPS_SECONDARYSTEREO: int
DSCBCAPS_WAVEMAPPED: int
DSCCAPS_EMULDRIVER: int
DSSCL_EXCLUSIVE: int
DSSCL_NORMAL: int
DSSCL_PRIORITY: int
DSSCL_WRITEPRIMARY: int
DSSPEAKER_GEOMETRY_MAX: int
DSSPEAKER_GEOMETRY_MIN: int
DSSPEAKER_GEOMETRY_NARROW: int
DSSPEAKER_GEOMETRY_WIDE: int
DSSPEAKER_HEADPHONE: int
DSSPEAKER_MONO: int
DSSPEAKER_QUAD: int
DSSPEAKER_STEREO: int
DSSPEAKER_SURROUND: int
DSBCAPSType = _win32typing.PyDSBCAPS
DSBFREQUENCY_MAX: int
DSBFREQUENCY_MIN: int
DSBFREQUENCY_ORIGINAL: int
DSBPAN_CENTER: int
DSBPAN_LEFT: int
DSBPAN_RIGHT: int
DSBPN_OFFSETSTOP: int
DSBSIZE_MAX: int
DSBSIZE_MIN: int
DSBUFFERDESCType = _win32typing.PyDSBUFFERDESC
DSBVOLUME_MAX: int
DSBVOLUME_MIN: int
DSCAPSType = _win32typing.PyDSCAPSType
DSCBCAPSType = _win32typing.PyDSCBCAPSType
DSCBLOCK_ENTIREBUFFER: int
DSCBSTART_LOOPING: int
DSCBSTATUS_CAPTURING: int
DSCBSTATUS_LOOPING: int
DSCBUFFERDESCType = _win32typing.PyDSCBUFFERDESC
DSCCAPSType = _win32typing.PyDSCCAPSType
DSERR_ACCESSDENIED: int
DSERR_ALLOCATED: int
DSERR_ALREADYINITIALIZED: int
DSERR_BADFORMAT: int
DSERR_BADSENDBUFFERGUID: int
DSERR_BUFFERLOST: int
DSERR_BUFFERTOOSMALL: int
DSERR_CONTROLUNAVAIL: int
DSERR_DS8_REQUIRED: int
DSERR_FXUNAVAILABLE: int
DSERR_GENERIC: int
DSERR_INVALIDCALL: int
DSERR_INVALIDPARAM: int
DSERR_NOAGGREGATION: int
DSERR_NODRIVER: int
DSERR_NOINTERFACE: int
DSERR_OBJECTNOTFOUND: int
DSERR_OTHERAPPHASPRIO: int
DSERR_OUTOFMEMORY: int
DSERR_PRIOLEVELNEEDED: int
DSERR_SENDLOOP: int
DSERR_UNINITIALIZED: int
DSERR_UNSUPPORTED: int
DS_NO_VIRTUALIZATION: int
DS_OK: int
IID_IDirectSound: _win32typing.PyIID
IID_IDirectSoundBuffer: _win32typing.PyIID
IID_IDirectSoundCapture: _win32typing.PyIID
IID_IDirectSoundCaptureBuffer: _win32typing.PyIID
IID_IDirectSoundNotify: _win32typing.PyIID



from _typeshed import Incomplete

WM_USER: int
DROPEFFECT_NONE: int
DROPEFFECT_COPY: int
DROPEFFECT_MOVE: int
DROPEFFECT_LINK: int
DROPEFFECT_SCROLL: int
FO_MOVE: int
FO_COPY: int
FO_DELETE: int
FO_RENAME: int
FOF_MULTIDESTFILES: int
FOF_CONFIRMMOUSE: int
FOF_SILENT: int
FOF_RENAMEONCOLLISION: int
FOF_NOCONFIRMATION: int
FOF_WANTMAPPINGHANDLE: int
FOF_ALLOWUNDO: int
FOF_FILESONLY: int
FOF_SIMPLEPROGRESS: int
FOF_NOCONFIRMMKDIR: int
FOF_NOERRORUI: int
FOF_NOCOPYSECURITYATTRIBS: int
FOF_NORECURSION: int
FOF_NO_CONNECTED_ELEMENTS: int
FOF_WANTNUKEWARNING: int
FOF_NORECURSEREPARSE: int
FOF_NO_UI: Incomplete
FOFX_NOSKIPJUNCTIONS: int
FOFX_PREFERHARDLINK: int
FOFX_SHOWELEVATIONPROMPT: int
FOFX_EARLYFAILURE: int
FOFX_PRESERVEFILEEXTENSIONS: int
FOFX_KEEPNEWERFILE: int
FOFX_NOCOPYHOOKS: int
FOFX_NOMINIMIZEBOX: int
FOFX_MOVEACLSACROSSVOLUMES: int
FOFX_DONTDISPLAYSOURCEPATH: int
FOFX_DONTDISPLAYDESTPATH: int
FOFX_REQUIREELEVATION: int
FOFX_COPYASDOWNLOAD: int
FOFX_DONTDISPLAYLOCATIONS: int
PO_DELETE: int
PO_RENAME: int
PO_PORTCHANGE: int
PO_REN_PORT: int
SE_ERR_FNF: int
SE_ERR_PNF: int
SE_ERR_ACCESSDENIED: int
SE_ERR_OOM: int
SE_ERR_DLLNOTFOUND: int
SE_ERR_SHARE: int
SE_ERR_ASSOCINCOMPLETE: int
SE_ERR_DDETIMEOUT: int
SE_ERR_DDEFAIL: int
SE_ERR_DDEBUSY: int
SE_ERR_NOASSOC: int
SEE_MASK_CLASSNAME: int
SEE_MASK_CLASSKEY: int
SEE_MASK_IDLIST: int
SEE_MASK_INVOKEIDLIST: int
SEE_MASK_ICON: int
SEE_MASK_HOTKEY: int
SEE_MASK_NOCLOSEPROCESS: int
SEE_MASK_CONNECTNETDRV: int
SEE_MASK_FLAG_DDEWAIT: int
SEE_MASK_DOENVSUBST: int
SEE_MASK_FLAG_NO_UI: int
SEE_MASK_UNICODE: int
SEE_MASK_NO_CONSOLE: int
SEE_MASK_ASYNCOK: int
SEE_MASK_HMONITOR: int
SHERB_NOCONFIRMATION: int
SHERB_NOPROGRESSUI: int
SHERB_NOSOUND: int
NIM_ADD: int
NIM_MODIFY: int
NIM_DELETE: int
NIF_MESSAGE: int
NIF_ICON: int
NIF_TIP: int
SHGFI_ICON: int
SHGFI_DISPLAYNAME: int
SHGFI_TYPENAME: int
SHGFI_ATTRIBUTES: int
SHGFI_ICONLOCATION: int
SHGFI_EXETYPE: int
SHGFI_SYSICONINDEX: int
SHGFI_LINKOVERLAY: int
SHGFI_SELECTED: int
SHGFI_ATTR_SPECIFIED: int
SHGFI_LARGEICON: int
SHGFI_SMALLICON: int
SHGFI_OPENICON: int
SHGFI_SHELLICONSIZE: int
SHGFI_PIDL: int
SHGFI_USEFILEATTRIBUTES: int
SHGNLI_PIDL: int
SHGNLI_PREFIXNAME: int
SHGNLI_NOUNIQUE: int
PRINTACTION_OPEN: int
PRINTACTION_PROPERTIES: int
PRINTACTION_NETINSTALL: int
PRINTACTION_NETINSTALLLINK: int
PRINTACTION_TESTPAGE: int
PRINTACTION_OPENNETPRN: int
PRINTACTION_DOCUMENTDEFAULTS: int
PRINTACTION_SERVERPROPERTIES: int
CMF_NORMAL: int
CMF_DEFAULTONLY: int
CMF_VERBSONLY: int
CMF_EXPLORE: int
CMF_NOVERBS: int
CMF_CANRENAME: int
CMF_NODEFAULT: int
CMF_INCLUDESTATIC: int
CMF_ITEMMENU: int
CMF_EXTENDEDVERBS: int
CMF_DISABLEDVERBS: int
CMF_ASYNCVERBSTATE: int
CMF_OPTIMIZEFORINVOKE: int
CMF_SYNCCASCADEMENU: int
CMF_DONOTPICKDEFAULT: int
CMF_RESERVED: int
GCS_VERBA: int
GCS_HELPTEXTA: int
GCS_VALIDATEA: int
GCS_VERBW: int
GCS_HELPTEXTW: int
GCS_VALIDATEW: int
GCS_UNICODE: int
GCS_VERB: int
GCS_HELPTEXT: int
GCS_VALIDATE: int
CMDSTR_NEWFOLDERA: str
CMDSTR_VIEWLISTA: str
CMDSTR_VIEWDETAILSA: str
CMDSTR_NEWFOLDER: str
CMDSTR_VIEWLIST: str
CMDSTR_VIEWDETAILS: str
CMIC_MASK_HOTKEY: int
CMIC_MASK_ICON: int
CMIC_MASK_FLAG_NO_UI: int
CMIC_MASK_UNICODE: int
CMIC_MASK_NO_CONSOLE: int
CMIC_MASK_ASYNCOK: int
CMIC_MASK_PTINVOKE: int
GIL_OPENICON: int
GIL_FORSHELL: int
GIL_ASYNC: int
GIL_DEFAULTICON: int
GIL_FORSHORTCUT: int
GIL_CHECKSHIELD: int
GIL_SIMULATEDOC: int
GIL_PERINSTANCE: int
GIL_PERCLASS: int
GIL_NOTFILENAME: int
GIL_DONTCACHE: int
GIL_SHIELD: int
GIL_FORCENOSHIELD: int
ISIOI_ICONFILE: int
ISIOI_ICONINDEX: int
ISIOI_SYSIMAGELISTINDEX: int
FVSIF_RECT: int
FVSIF_PINNED: int
FVSIF_NEWFAILED: int
FVSIF_NEWFILE: int
FVSIF_CANVIEWIT: int
FCIDM_SHVIEWFIRST: int
FCIDM_SHVIEWLAST: int
FCIDM_BROWSERFIRST: int
FCIDM_BROWSERLAST: int
FCIDM_GLOBALFIRST: int
FCIDM_GLOBALLAST: int
FCIDM_MENU_FILE: Incomplete
FCIDM_MENU_EDIT: Incomplete
FCIDM_MENU_VIEW: Incomplete
FCIDM_MENU_VIEW_SEP_OPTIONS: Incomplete
FCIDM_MENU_TOOLS: Incomplete
FCIDM_MENU_TOOLS_SEP_GOTO: Incomplete
FCIDM_MENU_HELP: Incomplete
FCIDM_MENU_FIND: Incomplete
FCIDM_MENU_EXPLORE: Incomplete
FCIDM_MENU_FAVORITES: Incomplete
FCIDM_TOOLBAR: Incomplete
FCIDM_STATUS: Incomplete
IDC_OFFLINE_HAND: int
SBSP_DEFBROWSER: int
SBSP_SAMEBROWSER: int
SBSP_NEWBROWSER: int
SBSP_DEFMODE: int
SBSP_OPENMODE: int
SBSP_EXPLOREMODE: int
SBSP_ABSOLUTE: int
SBSP_RELATIVE: int
SBSP_PARENT: int
SBSP_NAVIGATEBACK: int
SBSP_NAVIGATEFORWARD: int
SBSP_ALLOW_AUTONAVIGATE: int
SBSP_INITIATEDBYHLINKFRAME: int
SBSP_REDIRECT: int
SBSP_WRITENOHISTORY: int
SBSP_NOAUTOSELECT: int
FCW_STATUS: int
FCW_TOOLBAR: int
FCW_TREE: int
FCW_INTERNETBAR: int
FCW_PROGRESS: int
FCT_MERGE: int
FCT_CONFIGABLE: int
FCT_ADDTOEND: int
CDBOSC_SETFOCUS: int
CDBOSC_KILLFOCUS: int
CDBOSC_SELCHANGE: int
CDBOSC_RENAME: int
SVSI_DESELECT: int
SVSI_SELECT: int
SVSI_EDIT: int
SVSI_DESELECTOTHERS: int
SVSI_ENSUREVISIBLE: int
SVSI_FOCUSED: int
SVSI_TRANSLATEPT: int
SVGIO_BACKGROUND: int
SVGIO_SELECTION: int
SVGIO_ALLVIEW: int
SVGIO_CHECKED: Incomplete
SVGIO_TYPE_MASK: Incomplete
SVGIO_FLAG_VIEWORDER: int
STRRET_WSTR: int
STRRET_OFFSET: int
STRRET_CSTR: int
CSIDL_DESKTOP: int
CSIDL_INTERNET: int
CSIDL_PROGRAMS: int
CSIDL_CONTROLS: int
CSIDL_PRINTERS: int
CSIDL_PERSONAL: int
CSIDL_FAVORITES: int
CSIDL_STARTUP: int
CSIDL_RECENT: int
CSIDL_SENDTO: int
CSIDL_BITBUCKET: int
CSIDL_STARTMENU: int
CSIDL_MYDOCUMENTS: int
CSIDL_MYMUSIC: int
CSIDL_MYVIDEO: int
CSIDL_DESKTOPDIRECTORY: int
CSIDL_DRIVES: int
CSIDL_NETWORK: int
CSIDL_NETHOOD: int
CSIDL_FONTS: int
CSIDL_TEMPLATES: int
CSIDL_COMMON_STARTMENU: int
CSIDL_COMMON_PROGRAMS: int
CSIDL_COMMON_STARTUP: int
CSIDL_COMMON_DESKTOPDIRECTORY: int
CSIDL_APPDATA: int
CSIDL_PRINTHOOD: int
CSIDL_LOCAL_APPDATA: int
CSIDL_ALTSTARTUP: int
CSIDL_COMMON_ALTSTARTUP: int
CSIDL_COMMON_FAVORITES: int
CSIDL_INTERNET_CACHE: int
CSIDL_COOKIES: int
CSIDL_HISTORY: int
CSIDL_COMMON_APPDATA: int
CSIDL_WINDOWS: int
CSIDL_SYSTEM: int
CSIDL_PROGRAM_FILES: int
CSIDL_MYPICTURES: int
CSIDL_PROFILE: int
CSIDL_SYSTEMX86: int
CSIDL_PROGRAM_FILESX86: int
CSIDL_PROGRAM_FILES_COMMON: int
CSIDL_PROGRAM_FILES_COMMONX86: int
CSIDL_COMMON_TEMPLATES: int
CSIDL_COMMON_DOCUMENTS: int
CSIDL_COMMON_ADMINTOOLS: int
CSIDL_ADMINTOOLS: int
CSIDL_CONNECTIONS: int
CSIDL_COMMON_MUSIC: int
CSIDL_COMMON_PICTURES: int
CSIDL_COMMON_VIDEO: int
CSIDL_RESOURCES: int
CSIDL_RESOURCES_LOCALIZED: int
CSIDL_COMMON_OEM_LINKS: int
CSIDL_CDBURN_AREA: int
CSIDL_COMPUTERSNEARME: int
BIF_RETURNONLYFSDIRS: int
BIF_DONTGOBELOWDOMAIN: int
BIF_STATUSTEXT: int
BIF_RETURNFSANCESTORS: int
BIF_EDITBOX: int
BIF_VALIDATE: int
BIF_BROWSEFORCOMPUTER: int
BIF_BROWSEFORPRINTER: int
BIF_BROWSEINCLUDEFILES: int
BFFM_INITIALIZED: int
BFFM_SELCHANGED: int
BFFM_VALIDATEFAILEDA: int
BFFM_VALIDATEFAILEDW: int
BFFM_SETSTATUSTEXTA: Incomplete
BFFM_ENABLEOK: Incomplete
BFFM_SETSELECTIONA: Incomplete
BFFM_SETSELECTIONW: Incomplete
BFFM_SETSTATUSTEXTW: Incomplete
BFFM_SETSTATUSTEXT: Incomplete
BFFM_SETSELECTION: Incomplete
BFFM_VALIDATEFAILED: int
SFGAO_CANCOPY: int
SFGAO_CANMOVE: int
SFGAO_CANLINK: int
SFGAO_CANRENAME: int
SFGAO_CANDELETE: int
SFGAO_HASPROPSHEET: int
SFGAO_DROPTARGET: int
SFGAO_CAPABILITYMASK: int
SFGAO_LINK: int
SFGAO_SHARE: int
SFGAO_READONLY: int
SFGAO_GHOSTED: int
SFGAO_HIDDEN: int
SFGAO_DISPLAYATTRMASK: int
SFGAO_FILESYSANCESTOR: int
SFGAO_FOLDER: int
SFGAO_FILESYSTEM: int
SFGAO_HASSUBFOLDER: int
SFGAO_CONTENTSMASK: int
SFGAO_VALIDATE: int
SFGAO_REMOVABLE: int
SFGAO_COMPRESSED: int
SFGAO_BROWSABLE: int
SFGAO_NONENUMERATED: int
SFGAO_NEWCONTENT: int
SFGAO_STORAGE: int
DWFRF_NORMAL: int
DWFRF_DELETECONFIGDATA: int
DWFAF_HIDDEN: int
DBIM_MINSIZE: int
DBIM_MAXSIZE: int
DBIM_INTEGRAL: int
DBIM_ACTUAL: int
DBIM_TITLE: int
DBIM_MODEFLAGS: int
DBIM_BKCOLOR: int
DBIMF_NORMAL: int
DBIMF_VARIABLEHEIGHT: int
DBIMF_DEBOSSED: int
DBIMF_BKCOLOR: int
DBIF_VIEWMODE_NORMAL: int
DBIF_VIEWMODE_VERTICAL: int
DBIF_VIEWMODE_FLOATING: int
DBIF_VIEWMODE_TRANSPARENT: int
COMPONENT_TOP: int
COMP_TYPE_HTMLDOC: int
COMP_TYPE_PICTURE: int
COMP_TYPE_WEBSITE: int
COMP_TYPE_CONTROL: int
COMP_TYPE_CFHTML: int
COMP_TYPE_MAX: int
AD_APPLY_SAVE: int
AD_APPLY_HTMLGEN: int
AD_APPLY_REFRESH: int
AD_APPLY_ALL: Incomplete
AD_APPLY_FORCE: int
AD_APPLY_BUFFERED_REFRESH: int
WPSTYLE_CENTER: int
WPSTYLE_TILE: int
WPSTYLE_STRETCH: int
WPSTYLE_MAX: int
COMP_ELEM_TYPE: int
COMP_ELEM_CHECKED: int
COMP_ELEM_DIRTY: int
COMP_ELEM_NOSCROLL: int
COMP_ELEM_POS_LEFT: int
COMP_ELEM_POS_TOP: int
COMP_ELEM_SIZE_WIDTH: int
COMP_ELEM_SIZE_HEIGHT: int
COMP_ELEM_POS_ZINDEX: int
COMP_ELEM_SOURCE: int
COMP_ELEM_FRIENDLYNAME: int
COMP_ELEM_SUBSCRIBEDURL: int
ADDURL_SILENT: int
CFSTR_SHELLIDLIST: str
CFSTR_SHELLIDLISTOFFSET: str
CFSTR_NETRESOURCES: str
CFSTR_FILEDESCRIPTORA: str
CFSTR_FILEDESCRIPTORW: str
CFSTR_FILECONTENTS: str
CFSTR_FILENAMEA: str
CFSTR_FILENAMEW: str
CFSTR_PRINTERGROUP: str
CFSTR_FILENAMEMAPA: str
CFSTR_FILENAMEMAPW: str
CFSTR_SHELLURL: str
CFSTR_INETURLA: str
CFSTR_INETURLW: str
CFSTR_PREFERREDDROPEFFECT: str
CFSTR_PERFORMEDDROPEFFECT: str
CFSTR_PASTESUCCEEDED: str
CFSTR_INDRAGLOOP: str
CFSTR_DRAGCONTEXT: str
CFSTR_MOUNTEDVOLUME: str
CFSTR_PERSISTEDDATAOBJECT: str
CFSTR_TARGETCLSID: str
CFSTR_LOGICALPERFORMEDDROPEFFECT: str
CFSTR_AUTOPLAY_SHELLIDLISTS: str
CFSTR_FILEDESCRIPTOR: str
CFSTR_FILENAME: str
CFSTR_FILENAMEMAP: str
DVASPECT_SHORTNAME: int
SHCNE_RENAMEITEM: int
SHCNE_CREATE: int
SHCNE_DELETE: int
SHCNE_MKDIR: int
SHCNE_RMDIR: int
SHCNE_MEDIAINSERTED: int
SHCNE_MEDIAREMOVED: int
SHCNE_DRIVEREMOVED: int
SHCNE_DRIVEADD: int
SHCNE_NETSHARE: int
SHCNE_NETUNSHARE: int
SHCNE_ATTRIBUTES: int
SHCNE_UPDATEDIR: int
SHCNE_UPDATEITEM: int
SHCNE_SERVERDISCONNECT: int
SHCNE_UPDATEIMAGE: int
SHCNE_DRIVEADDGUI: int
SHCNE_RENAMEFOLDER: int
SHCNE_FREESPACE: int
SHCNE_EXTENDED_EVENT: int
SHCNE_ASSOCCHANGED: int
SHCNE_DISKEVENTS: int
SHCNE_GLOBALEVENTS: int
SHCNE_ALLEVENTS: int
SHCNE_INTERRUPT: int
SHCNEE_ORDERCHANGED: int
SHCNF_IDLIST: int
SHCNF_PATHA: int
SHCNF_PRINTERA: int
SHCNF_DWORD: int
SHCNF_PATHW: int
SHCNF_PRINTERW: int
SHCNF_TYPE: int
SHCNF_FLUSH: int
SHCNF_FLUSHNOWAIT: int
SHCNF_PATH: int
SHCNF_PRINTER: int
QIF_CACHED: int
QIF_DONTEXPANDFOLDER: int
SHARD_PIDL: int
SHARD_PATHA: int
SHARD_PATHW: int
SHARD_APPIDINFO: int
SHARD_APPIDINFOIDLIST: int
SHARD_LINK: int
SHARD_APPIDINFOLINK: int
SHARD_SHELLITEM: int
SHARD_PATH: int
SHGDFIL_FINDDATA: int
SHGDFIL_NETRESOURCE: int
SHGDFIL_DESCRIPTIONID: int
SHDID_ROOT_REGITEM: int
SHDID_FS_FILE: int
SHDID_FS_DIRECTORY: int
SHDID_FS_OTHER: int
SHDID_COMPUTER_DRIVE35: int
SHDID_COMPUTER_DRIVE525: int
SHDID_COMPUTER_REMOVABLE: int
SHDID_COMPUTER_FIXED: int
SHDID_COMPUTER_NETDRIVE: int
SHDID_COMPUTER_CDROM: int
SHDID_COMPUTER_RAMDISK: int
SHDID_COMPUTER_OTHER: int
SHDID_NET_DOMAIN: int
SHDID_NET_SERVER: int
SHDID_NET_SHARE: int
SHDID_NET_RESTOFNET: int
SHDID_NET_OTHER: int
PID_IS_URL: int
PID_IS_NAME: int
PID_IS_WORKINGDIR: int
PID_IS_HOTKEY: int
PID_IS_SHOWCMD: int
PID_IS_ICONINDEX: int
PID_IS_ICONFILE: int
PID_IS_WHATSNEW: int
PID_IS_AUTHOR: int
PID_IS_DESCRIPTION: int
PID_IS_COMMENT: int
PID_INTSITE_WHATSNEW: int
PID_INTSITE_AUTHOR: int
PID_INTSITE_LASTVISIT: int
PID_INTSITE_LASTMOD: int
PID_INTSITE_VISITCOUNT: int
PID_INTSITE_DESCRIPTION: int
PID_INTSITE_COMMENT: int
PID_INTSITE_FLAGS: int
PID_INTSITE_CONTENTLEN: int
PID_INTSITE_CONTENTCODE: int
PID_INTSITE_RECURSE: int
PID_INTSITE_WATCH: int
PID_INTSITE_SUBSCRIPTION: int
PID_INTSITE_URL: int
PID_INTSITE_TITLE: int
PID_INTSITE_CODEPAGE: int
PID_INTSITE_TRACKING: int
PIDISF_RECENTLYCHANGED: int
PIDISF_CACHEDSTICKY: int
PIDISF_CACHEIMAGES: int
PIDISF_FOLLOWALLLINKS: int
PIDISM_GLOBAL: int
PIDISM_WATCH: int
PIDISM_DONTWATCH: int
SSF_SHOWALLOBJECTS: int
SSF_SHOWEXTENSIONS: int
SSF_SHOWCOMPCOLOR: int
SSF_SHOWSYSFILES: int
SSF_DOUBLECLICKINWEBVIEW: int
SSF_SHOWATTRIBCOL: int
SSF_DESKTOPHTML: int
SSF_WIN95CLASSIC: int
SSF_DONTPRETTYPATH: int
SSF_SHOWINFOTIP: int
SSF_MAPNETDRVBUTTON: int
SSF_NOCONFIRMRECYCLE: int
SSF_HIDEICONS: int
ABM_NEW: int
ABM_REMOVE: int
ABM_QUERYPOS: int
ABM_SETPOS: int
ABM_GETSTATE: int
ABM_GETTASKBARPOS: int
ABM_ACTIVATE: int
ABM_GETAUTOHIDEBAR: int
ABM_SETAUTOHIDEBAR: int
ABM_WINDOWPOSCHANGED: int
ABN_STATECHANGE: int
ABN_POSCHANGED: int
ABN_FULLSCREENAPP: int
ABN_WINDOWARRANGE: int
ABS_AUTOHIDE: int
ABS_ALWAYSONTOP: int
ABE_LEFT: int
ABE_TOP: int
ABE_RIGHT: int
ABE_BOTTOM: int

def EIRESID(x): ...

SHCONTF_FOLDERS: int
SHCONTF_NONFOLDERS: int
SHCONTF_INCLUDEHIDDEN: int
SHCONTF_INIT_ON_FIRST_NEXT: int
SHCONTF_NETPRINTERSRCH: int
SHCONTF_SHAREABLE: int
SHCONTF_STORAGE: int
SHGDN_NORMAL: int
SHGDN_INFOLDER: int
SHGDN_FOREDITING: int
SHGDN_INCLUDE_NONFILESYS: int
SHGDN_FORADDRESSBAR: int
SHGDN_FORPARSING: int
BFO_NONE: int
BFO_BROWSER_PERSIST_SETTINGS: int
BFO_RENAME_FOLDER_OPTIONS_TOINTERNET: int
BFO_BOTH_OPTIONS: int
BIF_PREFER_INTERNET_SHORTCUT: int
BFO_BROWSE_NO_IN_NEW_PROCESS: int
BFO_ENABLE_HYPERLINK_TRACKING: int
BFO_USE_IE_OFFLINE_SUPPORT: int
BFO_SUBSTITUE_INTERNET_START_PAGE: int
BFO_USE_IE_LOGOBANDING: int
BFO_ADD_IE_TOCAPTIONBAR: int
BFO_USE_DIALUP_REF: int
BFO_USE_IE_TOOLBAR: int
BFO_NO_PARENT_FOLDER_SUPPORT: int
BFO_NO_REOPEN_NEXT_RESTART: int
BFO_GO_HOME_PAGE: int
BFO_PREFER_IEPROCESS: int
BFO_SHOW_NAVIGATION_CANCELLED: int
BFO_QUERY_ALL: int
PID_FINDDATA: int
PID_NETRESOURCE: int
PID_DESCRIPTIONID: int
PID_WHICHFOLDER: int
PID_NETWORKLOCATION: int
PID_COMPUTERNAME: int
PID_DISPLACED_FROM: int
PID_DISPLACED_DATE: int
PID_SYNC_COPY_IN: int
PID_MISC_STATUS: int
PID_MISC_ACCESSCOUNT: int
PID_MISC_OWNER: int
PID_HTMLINFOTIPFILE: int
PID_MISC_PICS: int
PID_DISPLAY_PROPERTIES: int
PID_INTROTEXT: int
PIDSI_ARTIST: int
PIDSI_SONGTITLE: int
PIDSI_ALBUM: int
PIDSI_YEAR: int
PIDSI_COMMENT: int
PIDSI_TRACK: int
PIDSI_GENRE: int
PIDSI_LYRICS: int
PIDDRSI_PROTECTED: int
PIDDRSI_DESCRIPTION: int
PIDDRSI_PLAYCOUNT: int
PIDDRSI_PLAYSTARTS: int
PIDDRSI_PLAYEXPIRES: int
PIDVSI_STREAM_NAME: int
PIDVSI_FRAME_WIDTH: int
PIDVSI_FRAME_HEIGHT: int
PIDVSI_TIMELENGTH: int
PIDVSI_FRAME_COUNT: int
PIDVSI_FRAME_RATE: int
PIDVSI_DATA_RATE: int
PIDVSI_SAMPLE_SIZE: int
PIDVSI_COMPRESSION: int
PIDVSI_STREAM_NUMBER: int
PIDASI_FORMAT: int
PIDASI_TIMELENGTH: int
PIDASI_AVG_DATA_RATE: int
PIDASI_SAMPLE_RATE: int
PIDASI_SAMPLE_SIZE: int
PIDASI_CHANNEL_COUNT: int
PIDASI_STREAM_NUMBER: int
PIDASI_STREAM_NAME: int
PIDASI_COMPRESSION: int
PID_CONTROLPANEL_CATEGORY: int
PID_VOLUME_FREE: int
PID_VOLUME_CAPACITY: int
PID_VOLUME_FILESYSTEM: int
PID_SHARE_CSC_STATUS: int
PID_LINK_TARGET: int
PID_QUERY_RANK: int
PROPSETFLAG_DEFAULT: int
PROPSETFLAG_NONSIMPLE: int
PROPSETFLAG_ANSI: int
PROPSETFLAG_UNBUFFERED: int
PROPSETFLAG_CASE_SENSITIVE: int
PROPSET_BEHAVIOR_CASE_SENSITIVE: int
PID_DICTIONARY: int
PID_CODEPAGE: int
PID_FIRST_USABLE: int
PID_FIRST_NAME_DEFAULT: int
PID_LOCALE: int
PID_MODIFY_TIME: int
PID_SECURITY: int
PID_BEHAVIOR: int
PID_ILLEGAL: int
PID_MIN_READONLY: int
PID_MAX_READONLY: int
PIDDI_THUMBNAIL: int
PIDSI_TITLE: int
PIDSI_SUBJECT: int
PIDSI_AUTHOR: int
PIDSI_KEYWORDS: int
PIDSI_COMMENTS: int
PIDSI_TEMPLATE: int
PIDSI_LASTAUTHOR: int
PIDSI_REVNUMBER: int
PIDSI_EDITTIME: int
PIDSI_LASTPRINTED: int
PIDSI_CREATE_DTM: int
PIDSI_LASTSAVE_DTM: int
PIDSI_PAGECOUNT: int
PIDSI_WORDCOUNT: int
PIDSI_CHARCOUNT: int
PIDSI_THUMBNAIL: int
PIDSI_APPNAME: int
PIDSI_DOC_SECURITY: int
PIDDSI_CATEGORY: int
PIDDSI_PRESFORMAT: int
PIDDSI_BYTECOUNT: int
PIDDSI_LINECOUNT: int
PIDDSI_PARCOUNT: int
PIDDSI_SLIDECOUNT: int
PIDDSI_NOTECOUNT: int
PIDDSI_HIDDENCOUNT: int
PIDDSI_MMCLIPCOUNT: int
PIDDSI_SCALE: int
PIDDSI_HEADINGPAIR: int
PIDDSI_DOCPARTS: int
PIDDSI_MANAGER: int
PIDDSI_COMPANY: int
PIDDSI_LINKSDIRTY: int
PIDMSI_EDITOR: int
PIDMSI_SUPPLIER: int
PIDMSI_SOURCE: int
PIDMSI_SEQUENCE_NO: int
PIDMSI_PROJECT: int
PIDMSI_STATUS: int
PIDMSI_OWNER: int
PIDMSI_RATING: int
PIDMSI_PRODUCTION: int
PIDMSI_COPYRIGHT: int
PRSPEC_INVALID: int
PRSPEC_LPWSTR: int
PRSPEC_PROPID: int
SHCIDS_ALLFIELDS: int
SHCIDS_CANONICALONLY: int
SHCIDS_BITMASK: int
SHCIDS_COLUMNMASK: int
SFGAO_CANMONIKER: int
SFGAO_HASSTORAGE: int
SFGAO_STREAM: int
SFGAO_STORAGEANCESTOR: int
SFGAO_STORAGECAPMASK: int
MAXPROPPAGES: int
PSP_DEFAULT: int
PSP_DLGINDIRECT: int
PSP_USEHICON: int
PSP_USEICONID: int
PSP_USETITLE: int
PSP_RTLREADING: int
PSP_HASHELP: int
PSP_USEREFPARENT: int
PSP_USECALLBACK: int
PSP_PREMATURE: int
PSP_HIDEHEADER: int
PSP_USEHEADERTITLE: int
PSP_USEHEADERSUBTITLE: int
PSP_USEFUSIONCONTEXT: int
PSPCB_ADDREF: int
PSPCB_RELEASE: int
PSPCB_CREATE: int
PSH_DEFAULT: int
PSH_PROPTITLE: int
PSH_USEHICON: int
PSH_USEICONID: int
PSH_PROPSHEETPAGE: int
PSH_WIZARDHASFINISH: int
PSH_WIZARD: int
PSH_USEPSTARTPAGE: int
PSH_NOAPPLYNOW: int
PSH_USECALLBACK: int
PSH_HASHELP: int
PSH_MODELESS: int
PSH_RTLREADING: int
PSH_WIZARDCONTEXTHELP: int
PSH_WIZARD97: int
PSH_WATERMARK: int
PSH_USEHBMWATERMARK: int
PSH_USEHPLWATERMARK: int
PSH_STRETCHWATERMARK: int
PSH_HEADER: int
PSH_USEHBMHEADER: int
PSH_USEPAGELANG: int
PSH_WIZARD_LITE: int
PSH_NOCONTEXTHELP: int
PSCB_INITIALIZED: int
PSCB_PRECREATE: int
PSCB_BUTTONPRESSED: int
PSNRET_NOERROR: int
PSNRET_INVALID: int
PSNRET_INVALID_NOCHANGEPAGE: int
PSNRET_MESSAGEHANDLED: int
PSWIZB_BACK: int
PSWIZB_NEXT: int
PSWIZB_FINISH: int
PSWIZB_DISABLEDFINISH: int
PSBTN_BACK: int
PSBTN_NEXT: int
PSBTN_FINISH: int
PSBTN_OK: int
PSBTN_APPLYNOW: int
PSBTN_CANCEL: int
PSBTN_HELP: int
PSBTN_MAX: int
ID_PSRESTARTWINDOWS: int
ID_PSREBOOTSYSTEM: Incomplete
WIZ_CXDLG: int
WIZ_CYDLG: int
WIZ_CXBMP: int
WIZ_BODYX: int
WIZ_BODYCX: int
PROP_SM_CXDLG: int
PROP_SM_CYDLG: int
PROP_MED_CXDLG: int
PROP_MED_CYDLG: int
PROP_LG_CXDLG: int
PROP_LG_CYDLG: int
ISOLATION_AWARE_USE_STATIC_LIBRARY: int
ISOLATION_AWARE_BUILD_STATIC_LIBRARY: int
SHCOLSTATE_TYPE_STR: int
SHCOLSTATE_TYPE_INT: int
SHCOLSTATE_TYPE_DATE: int
SHCOLSTATE_TYPEMASK: int
SHCOLSTATE_ONBYDEFAULT: int
SHCOLSTATE_SLOW: int
SHCOLSTATE_EXTENDED: int
SHCOLSTATE_SECONDARYUI: int
SHCOLSTATE_HIDDEN: int
SHCOLSTATE_PREFER_VARCMP: int
FWF_AUTOARRANGE: int
FWF_ABBREVIATEDNAMES: int
FWF_SNAPTOGRID: int
FWF_OWNERDATA: int
FWF_BESTFITWINDOW: int
FWF_DESKTOP: int
FWF_SINGLESEL: int
FWF_NOSUBFOLDERS: int
FWF_TRANSPARENT: int
FWF_NOCLIENTEDGE: int
FWF_NOSCROLL: int
FWF_ALIGNLEFT: int
FWF_NOICONS: int
FWF_SHOWSELALWAYS: int
FWF_NOVISIBLE: int
FWF_SINGLECLICKACTIVATE: int
FWF_NOWEBVIEW: int
FWF_HIDEFILENAMES: int
FWF_CHECKSELECT: int
FVM_FIRST: int
FVM_ICON: int
FVM_SMALLICON: int
FVM_LIST: int
FVM_DETAILS: int
FVM_THUMBNAIL: int
FVM_TILE: int
FVM_THUMBSTRIP: int
SVUIA_DEACTIVATE: int
SVUIA_ACTIVATE_NOFOCUS: int
SVUIA_ACTIVATE_FOCUS: int
SVUIA_INPLACEACTIVATE: int
SHCNRF_InterruptLevel: int
SHCNRF_ShellLevel: int
SHCNRF_RecursiveInterrupt: int
SHCNRF_NewDelivery: int
FD_CLSID: int
FD_SIZEPOINT: int
FD_ATTRIBUTES: int
FD_CREATETIME: int
FD_ACCESSTIME: int
FD_WRITESTIME: int
FD_FILESIZE: int
FD_PROGRESSUI: int
FD_LINKUI: int
ASSOCF_INIT_NOREMAPCLSID: int
ASSOCF_INIT_BYEXENAME: int
ASSOCF_OPEN_BYEXENAME: int
ASSOCF_INIT_DEFAULTTOSTAR: int
ASSOCF_INIT_DEFAULTTOFOLDER: int
ASSOCF_NOUSERSETTINGS: int
ASSOCF_NOTRUNCATE: int
ASSOCF_VERIFY: int
ASSOCF_REMAPRUNDLL: int
ASSOCF_NOFIXUPS: int
ASSOCF_IGNOREBASECLASS: int
ASSOCSTR_COMMAND: int
ASSOCSTR_EXECUTABLE: int
ASSOCSTR_FRIENDLYDOCNAME: int
ASSOCSTR_FRIENDLYAPPNAME: int
ASSOCSTR_NOOPEN: int
ASSOCSTR_SHELLNEWVALUE: int
ASSOCSTR_DDECOMMAND: int
ASSOCSTR_DDEIFEXEC: int
ASSOCSTR_DDEAPPLICATION: int
ASSOCSTR_DDETOPIC: int
ASSOCSTR_INFOTIP: int
ASSOCSTR_QUICKTIP: int
ASSOCSTR_TILEINFO: int
ASSOCSTR_CONTENTTYPE: int
ASSOCSTR_DEFAULTICON: int
ASSOCSTR_SHELLEXTENSION: int
ASSOCKEY_SHELLEXECCLASS: int
ASSOCKEY_APP: int
ASSOCKEY_CLASS: int
ASSOCKEY_BASECLASS: int
ASSOCDATA_MSIDESCRIPTOR: int
ASSOCDATA_NOACTIVATEHANDLER: int
ASSOCDATA_QUERYCLASSSTORE: int
ASSOCDATA_HASPERUSERASSOC: int
ASSOCDATA_EDITFLAGS: int
ASSOCDATA_VALUE: int
SHGVSPB_PERUSER: int
SHGVSPB_ALLUSERS: int
SHGVSPB_PERFOLDER: int
SHGVSPB_ALLFOLDERS: int
SHGVSPB_INHERIT: int
SHGVSPB_ROAM: int
SHGVSPB_NOAUTODEFAULTS: int
SHGVSPB_FOLDER: Incomplete
SHGVSPB_FOLDERNODEFAULTS: Incomplete
SHGVSPB_USERDEFAULTS: Incomplete
SHGVSPB_GLOBALDEAFAULTS: Incomplete
SFVM_REARRANGE: int
SFVM_ADDOBJECT: int
SFVM_REMOVEOBJECT: int
SFVM_UPDATEOBJECT: int
SFVM_GETSELECTEDOBJECTS: int
SFVM_SETITEMPOS: int
SFVM_SETCLIPBOARD: int
SFVM_SETPOINTS: int
SLDF_HAS_ID_LIST: int
SLDF_HAS_LINK_INFO: int
SLDF_HAS_NAME: int
SLDF_HAS_RELPATH: int
SLDF_HAS_WORKINGDIR: int
SLDF_HAS_ARGS: int
SLDF_HAS_ICONLOCATION: int
SLDF_UNICODE: int
SLDF_FORCE_NO_LINKINFO: int
SLDF_HAS_EXP_SZ: int
SLDF_RUN_IN_SEPARATE: int
SLDF_HAS_LOGO3ID: int
SLDF_HAS_DARWINID: int
SLDF_RUNAS_USER: int
SLDF_NO_PIDL_ALIAS: int
SLDF_FORCE_UNCNAME: int
SLDF_HAS_EXP_ICON_SZ: int
SLDF_RUN_WITH_SHIMLAYER: int
SLDF_RESERVED: int
EXP_SPECIAL_FOLDER_SIG: int
NT_CONSOLE_PROPS_SIG: int
NT_FE_CONSOLE_PROPS_SIG: int
EXP_DARWIN_ID_SIG: int
EXP_LOGO3_ID_SIG: int
EXP_SZ_ICON_SIG: int
EXP_SZ_LINK_SIG: int
IURL_SETURL_FL_GUESS_PROTOCOL: int
IURL_SETURL_FL_USE_DEFAULT_PROTOCOL: int
IURL_INVOKECOMMAND_FL_ALLOW_UI: int
IURL_INVOKECOMMAND_FL_USE_DEFAULT_VERB: int
IURL_INVOKECOMMAND_FL_DDEWAIT: int
IS_NORMAL: int
IS_FULLSCREEN: int
IS_SPLIT: int
IS_VALIDSIZESTATEBITS: Incomplete
IS_VALIDSTATEBITS: Incomplete
AD_APPLY_DYNAMICREFRESH: int
COMP_ELEM_ORIGINAL_CSI: int
COMP_ELEM_RESTORED_CSI: int
COMP_ELEM_CURITEMSTATE: int
COMP_ELEM_ALL: Incomplete
DTI_ADDUI_DEFAULT: int
DTI_ADDUI_DISPSUBWIZARD: int
DTI_ADDUI_POSITIONITEM: int
COMPONENT_DEFAULT_LEFT: int
COMPONENT_DEFAULT_TOP: int
SSM_CLEAR: int
SSM_SET: int
SSM_REFRESH: int
SSM_UPDATE: int
SCHEME_DISPLAY: int
SCHEME_EDIT: int
SCHEME_LOCAL: int
SCHEME_GLOBAL: int
SCHEME_REFRESH: int
SCHEME_UPDATE: int
SCHEME_DONOTUSE: int
SCHEME_CREATE: int
GADOF_DIRTY: int
EVCF_HASSETTINGS: int
EVCF_ENABLEBYDEFAULT: int
EVCF_REMOVEFROMLIST: int
EVCF_ENABLEBYDEFAULT_AUTO: int
EVCF_DONTSHOWIFZERO: int
EVCF_SETTINGSMODE: int
EVCF_OUTOFDISKSPACE: int
EVCCBF_LASTNOTIFICATION: int
EBO_NONE: int
EBO_NAVIGATEONCE: int
EBO_SHOWFRAMES: int
EBO_ALWAYSNAVIGATE: int
EBO_NOTRAVELLOG: int
EBO_NOWRAPPERWINDOW: int
EBF_NONE: int
EBF_SELECTFROMDATAOBJECT: int
EBF_NODROPTARGET: int
ECS_ENABLED: int
ECS_DISABLED: int
ECS_HIDDEN: int
ECS_CHECKBOX: int
ECS_CHECKED: int
ECF_HASSUBCOMMANDS: int
ECF_HASSPLITBUTTON: int
ECF_HIDELABEL: int
ECF_ISSEPARATOR: int
ECF_HASLUASHIELD: int
SIATTRIBFLAGS_AND: int
SIATTRIBFLAGS_OR: int
SIATTRIBFLAGS_APPCOMPAT: int
SIATTRIBFLAGS_MASK: int
SIGDN_NORMALDISPLAY: int
SIGDN_PARENTRELATIVEPARSING: int
SIGDN_DESKTOPABSOLUTEPARSING: int
SIGDN_PARENTRELATIVEEDITING: int
SIGDN_DESKTOPABSOLUTEEDITING: int
SIGDN_FILESYSPATH: int
SIGDN_URL: int
SIGDN_PARENTRELATIVEFORADDRESSBAR: int
SIGDN_PARENTRELATIVE: int
SICHINT_DISPLAY: Incomplete
SICHINT_ALLFIELDS: int
SICHINT_CANONICAL: int
ASSOCCLASS_SHELL_KEY: int
ASSOCCLASS_PROGID_KEY: int
ASSOCCLASS_PROGID_STR: int
ASSOCCLASS_CLSID_KEY: int
ASSOCCLASS_CLSID_STR: int
ASSOCCLASS_APP_KEY: int
ASSOCCLASS_APP_STR: int
ASSOCCLASS_SYSTEM_STR: int
ASSOCCLASS_FOLDER: int
ASSOCCLASS_STAR: int
NSTCS_HASEXPANDOS: int
NSTCS_HASLINES: int
NSTCS_SINGLECLICKEXPAND: int
NSTCS_FULLROWSELECT: int
NSTCS_SPRINGEXPAND: int
NSTCS_HORIZONTALSCROLL: int
NSTCS_ROOTHASEXPANDO: int
NSTCS_SHOWSELECTIONALWAYS: int
NSTCS_NOINFOTIP: int
NSTCS_EVENHEIGHT: int
NSTCS_NOREPLACEOPEN: int
NSTCS_DISABLEDRAGDROP: int
NSTCS_NOORDERSTREAM: int
NSTCS_RICHTOOLTIP: int
NSTCS_BORDER: int
NSTCS_NOEDITLABELS: int
NSTCS_TABSTOP: int
NSTCS_FAVORITESMODE: int
NSTCS_AUTOHSCROLL: int
NSTCS_FADEINOUTEXPANDOS: int
NSTCS_EMPTYTEXT: int
NSTCS_CHECKBOXES: int
NSTCS_PARTIALCHECKBOXES: int
NSTCS_EXCLUSIONCHECKBOXES: int
NSTCS_DIMMEDCHECKBOXES: int
NSTCS_NOINDENTCHECKS: int
NSTCS_ALLOWJUNCTIONS: int
NSTCS_SHOWTABSBUTTON: int
NSTCS_SHOWDELETEBUTTON: int
NSTCS_SHOWREFRESHBUTTON: int
NSTCRS_VISIBLE: int
NSTCRS_HIDDEN: int
NSTCRS_EXPANDED: int
NSTCIS_NONE: int
NSTCIS_SELECTED: int
NSTCIS_EXPANDED: int
NSTCIS_BOLD: int
NSTCIS_DISABLED: int
NSTCGNI_NEXT: int
NSTCGNI_NEXTVISIBLE: int
NSTCGNI_PREV: int
NSTCGNI_PREVVISIBLE: int
NSTCGNI_PARENT: int
NSTCGNI_CHILD: int
NSTCGNI_FIRSTVISIBLE: int
NSTCGNI_LASTVISIBLE: int
CLSID_ExplorerBrowser: str
IBrowserFrame_Methods: Incomplete
ICategorizer_Methods: Incomplete
ICategoryProvider_Methods: Incomplete
IContextMenu_Methods: Incomplete
IExplorerCommand_Methods: Incomplete
IExplorerCommandProvider_Methods: Incomplete
IOleWindow_Methods: Incomplete
IPersist_Methods: Incomplete
IPersistFolder_Methods: Incomplete
IPersistFolder2_Methods: Incomplete
IShellExtInit_Methods: Incomplete
IShellView_Methods: Incomplete
IShellFolder_Methods: Incomplete
IShellFolder2_Methods: Incomplete
GPS_DEFAULT: int
GPS_HANDLERPROPERTIESONLY: int
GPS_READWRITE: int
GPS_TEMPORARY: int
GPS_FASTPROPERTIESONLY: int
GPS_OPENSLOWITEM: int
GPS_DELAYCREATION: int
GPS_BESTEFFORT: int
GPS_MASK_VALID: int
STR_AVOID_DRIVE_RESTRICTION_POLICY: str
STR_BIND_DELEGATE_CREATE_OBJECT: str
STR_BIND_FOLDERS_READ_ONLY: str
STR_BIND_FOLDER_ENUM_MODE: str
STR_BIND_FORCE_FOLDER_SHORTCUT_RESOLVE: str
STR_DONT_PARSE_RELATIVE: str
STR_DONT_RESOLVE_LINK: str
STR_FILE_SYS_BIND_DATA: str
STR_GET_ASYNC_HANDLER: str
STR_GPS_BESTEFFORT: str
STR_GPS_DELAYCREATION: str
STR_GPS_FASTPROPERTIESONLY: str
STR_GPS_HANDLERPROPERTIESONLY: str
STR_GPS_NO_OPLOCK: str
STR_GPS_OPENSLOWITEM: str
STR_IFILTER_FORCE_TEXT_FILTER_FALLBACK: str
STR_IFILTER_LOAD_DEFINED_FILTER: str
STR_INTERNAL_NAVIGATE: str
STR_INTERNETFOLDER_PARSE_ONLY_URLMON_BINDABLE: str
STR_ITEM_CACHE_CONTEXT: str
STR_NO_VALIDATE_FILENAME_CHARS: str
STR_PARSE_ALLOW_INTERNET_SHELL_FOLDERS: str
STR_PARSE_AND_CREATE_ITEM: str
STR_PARSE_DONT_REQUIRE_VALIDATED_URLS: str
STR_PARSE_EXPLICIT_ASSOCIATION_SUCCESSFUL: str
STR_PARSE_PARTIAL_IDLIST: str
STR_PARSE_PREFER_FOLDER_BROWSING: str
STR_PARSE_PREFER_WEB_BROWSING: str
STR_PARSE_PROPERTYSTORE: str
STR_PARSE_SHELL_PROTOCOL_TO_FILE_OBJECTS: str
STR_PARSE_SHOW_NET_DIAGNOSTICS_UI: str
STR_PARSE_SKIP_NET_CACHE: str
STR_PARSE_TRANSLATE_ALIASES: str
STR_PARSE_WITH_EXPLICIT_ASSOCAPP: str
STR_PARSE_WITH_EXPLICIT_PROGID: str
STR_PARSE_WITH_PROPERTIES: str
STR_SKIP_BINDING_CLSID: str
STR_TRACK_CLSID: str
KF_REDIRECTION_CAPABILITIES_ALLOW_ALL: int
KF_REDIRECTION_CAPABILITIES_REDIRECTABLE: int
KF_REDIRECTION_CAPABILITIES_DENY_ALL: int
KF_REDIRECTION_CAPABILITIES_DENY_POLICY_REDIRECTED: int
KF_REDIRECTION_CAPABILITIES_DENY_POLICY: int
KF_REDIRECTION_CAPABILITIES_DENY_PERMISSIONS: int
KF_REDIRECT_USER_EXCLUSIVE: int
KF_REDIRECT_COPY_SOURCE_DACL: int
KF_REDIRECT_OWNER_USER: int
KF_REDIRECT_SET_OWNER_EXPLICIT: int
KF_REDIRECT_CHECK_ONLY: int
KF_REDIRECT_WITH_UI: int
KF_REDIRECT_UNPIN: int
KF_REDIRECT_PIN: int
KF_REDIRECT_COPY_CONTENTS: int
KF_REDIRECT_DEL_SOURCE_CONTENTS: int
KF_REDIRECT_EXCLUDE_ALL_KNOWN_SUBFOLDERS: int
KF_CATEGORY_VIRTUAL: int
KF_CATEGORY_FIXED: int
KF_CATEGORY_COMMON: int
KF_CATEGORY_PERUSER: int
FFFP_EXACTMATCH: int
FFFP_NEARESTPARENTMATCH: int
KF_FLAG_CREATE: int
KF_FLAG_DONT_VERIFY: int
KF_FLAG_DONT_UNEXPAND: int
KF_FLAG_NO_ALIAS: int
KF_FLAG_INIT: int
KF_FLAG_DEFAULT_PATH: int
KF_FLAG_NOT_PARENT_RELATIVE: int
KF_FLAG_SIMPLE_IDLIST: int
ADLT_RECENT: int
ADLT_FREQUENT: int
KDC_FREQUENT: int
KDC_RECENT: int
LFF_FORCEFILESYSTEM: int
LFF_STORAGEITEMS: int
LFF_ALLITEMS: int
DSFT_DETECT: int
DSFT_PRIVATE: int
DSFT_PUBLIC: int
LOF_DEFAULT: int
LOF_PINNEDTONAVPANE: int
LOF_MASK_ALL: int
LSF_FAILIFTHERE: int
LSF_OVERRIDEEXISTING: int
LSF_MAKEUNIQUENAME: int
TSF_NORMAL: int
TSF_FAIL_EXIST: int
TSF_RENAME_EXIST: int
TSF_OVERWRITE_EXIST: int
TSF_ALLOW_DECRYPTION: int
TSF_NO_SECURITY: int
TSF_COPY_CREATION_TIME: int
TSF_COPY_WRITE_TIME: int
TSF_USE_FULL_ACCESS: int
TSF_DELETE_RECYCLE_IF_POSSIBLE: int
TSF_COPY_HARD_LINK: int
TSF_COPY_LOCALIZED_NAME: int
TSF_MOVE_AS_COPY_DELETE: int
TSF_SUSPEND_SHELLEVENTS: int
TS_NONE: int
TS_PERFORMING: int
TS_PREPARING: int
TS_INDETERMINATE: int
COPYENGINE_S_YES: int
COPYENGINE_S_NOT_HANDLED: int
COPYENGINE_S_USER_RETRY: int
COPYENGINE_S_USER_IGNORED: int
COPYENGINE_S_MERGE: int
COPYENGINE_S_DONT_PROCESS_CHILDREN: int
COPYENGINE_S_ALREADY_DONE: int
COPYENGINE_S_PENDING: int
COPYENGINE_S_KEEP_BOTH: int
COPYENGINE_S_CLOSE_PROGRAM: int
COPYENGINE_S_COLLISIONRESOLVED: int
COPYENGINE_E_USER_CANCELLED: int
COPYENGINE_E_CANCELLED: int
COPYENGINE_E_REQUIRES_ELEVATION: int
COPYENGINE_E_SAME_FILE: int
COPYENGINE_E_DIFF_DIR: int
COPYENGINE_E_MANY_SRC_1_DEST: int
COPYENGINE_E_DEST_SUBTREE: int
COPYENGINE_E_DEST_SAME_TREE: int
COPYENGINE_E_FLD_IS_FILE_DEST: int
COPYENGINE_E_FILE_IS_FLD_DEST: int
COPYENGINE_E_FILE_TOO_LARGE: int
COPYENGINE_E_REMOVABLE_FULL: int
COPYENGINE_E_DEST_IS_RO_CD: int
COPYENGINE_E_DEST_IS_RW_CD: int
COPYENGINE_E_DEST_IS_R_CD: int
COPYENGINE_E_DEST_IS_RO_DVD: int
COPYENGINE_E_DEST_IS_RW_DVD: int
COPYENGINE_E_DEST_IS_R_DVD: int
COPYENGINE_E_SRC_IS_RO_CD: int
COPYENGINE_E_SRC_IS_RW_CD: int
COPYENGINE_E_SRC_IS_R_CD: int
COPYENGINE_E_SRC_IS_RO_DVD: int
COPYENGINE_E_SRC_IS_RW_DVD: int
COPYENGINE_E_SRC_IS_R_DVD: int
COPYENGINE_E_INVALID_FILES_SRC: int
COPYENGINE_E_INVALID_FILES_DEST: int
COPYENGINE_E_PATH_TOO_DEEP_SRC: int
COPYENGINE_E_PATH_TOO_DEEP_DEST: int
COPYENGINE_E_ROOT_DIR_SRC: int
COPYENGINE_E_ROOT_DIR_DEST: int
COPYENGINE_E_ACCESS_DENIED_SRC: int
COPYENGINE_E_ACCESS_DENIED_DEST: int
COPYENGINE_E_PATH_NOT_FOUND_SRC: int
COPYENGINE_E_PATH_NOT_FOUND_DEST: int
COPYENGINE_E_NET_DISCONNECT_SRC: int
COPYENGINE_E_NET_DISCONNECT_DEST: int
COPYENGINE_E_SHARING_VIOLATION_SRC: int
COPYENGINE_E_SHARING_VIOLATION_DEST: int
COPYENGINE_E_ALREADY_EXISTS_NORMAL: int
COPYENGINE_E_ALREADY_EXISTS_READONLY: int
COPYENGINE_E_ALREADY_EXISTS_SYSTEM: int
COPYENGINE_E_ALREADY_EXISTS_FOLDER: int
COPYENGINE_E_STREAM_LOSS: int
COPYENGINE_E_EA_LOSS: int
COPYENGINE_E_PROPERTY_LOSS: int
COPYENGINE_E_PROPERTIES_LOSS: int
COPYENGINE_E_ENCRYPTION_LOSS: int
COPYENGINE_E_DISK_FULL: int
COPYENGINE_E_DISK_FULL_CLEAN: int
COPYENGINE_E_EA_NOT_SUPPORTED: int
COPYENGINE_E_CANT_REACH_SOURCE: int
COPYENGINE_E_RECYCLE_UNKNOWN_ERROR: int
COPYENGINE_E_RECYCLE_FORCE_NUKE: int
COPYENGINE_E_RECYCLE_SIZE_TOO_BIG: int
COPYENGINE_E_RECYCLE_PATH_TOO_LONG: int
COPYENGINE_E_RECYCLE_BIN_NOT_FOUND: int
COPYENGINE_E_NEWFILE_NAME_TOO_LONG: int
COPYENGINE_E_NEWFOLDER_NAME_TOO_LONG: int
COPYENGINE_E_DIR_NOT_EMPTY: int
COPYENGINE_E_FAT_MAX_IN_ROOT: int
COPYENGINE_E_ACCESSDENIED_READONLY: int
COPYENGINE_E_REDIRECTED_TO_WEBPAGE: int
COPYENGINE_E_SERVER_BAD_FILE_TYPE: int
FOLDERID_NetworkFolder: str
FOLDERID_ComputerFolder: str
FOLDERID_InternetFolder: str
FOLDERID_ControlPanelFolder: str
FOLDERID_PrintersFolder: str
FOLDERID_SyncManagerFolder: str
FOLDERID_SyncSetupFolder: str
FOLDERID_ConflictFolder: str
FOLDERID_SyncResultsFolder: str
FOLDERID_RecycleBinFolder: str
FOLDERID_ConnectionsFolder: str
FOLDERID_Fonts: str
FOLDERID_Desktop: str
FOLDERID_Startup: str
FOLDERID_Programs: str
FOLDERID_StartMenu: str
FOLDERID_Recent: str
FOLDERID_SendTo: str
FOLDERID_Documents: str
FOLDERID_Favorites: str
FOLDERID_NetHood: str
FOLDERID_PrintHood: str
FOLDERID_Templates: str
FOLDERID_CommonStartup: str
FOLDERID_CommonPrograms: str
FOLDERID_CommonStartMenu: str
FOLDERID_PublicDesktop: str
FOLDERID_ProgramData: str
FOLDERID_CommonTemplates: str
FOLDERID_PublicDocuments: str
FOLDERID_RoamingAppData: str
FOLDERID_LocalAppData: str
FOLDERID_LocalAppDataLow: str
FOLDERID_InternetCache: str
FOLDERID_Cookies: str
FOLDERID_History: str
FOLDERID_System: str
FOLDERID_SystemX86: str
FOLDERID_Windows: str
FOLDERID_Profile: str
FOLDERID_Pictures: str
FOLDERID_ProgramFilesX86: str
FOLDERID_ProgramFilesCommonX86: str
FOLDERID_ProgramFilesX64: str
FOLDERID_ProgramFilesCommonX64: str
FOLDERID_ProgramFiles: str
FOLDERID_ProgramFilesCommon: str
FOLDERID_UserProgramFiles: str
FOLDERID_UserProgramFilesCommon: str
FOLDERID_AdminTools: str
FOLDERID_CommonAdminTools: str
FOLDERID_Music: str
FOLDERID_Videos: str
FOLDERID_Ringtones: str
FOLDERID_PublicPictures: str
FOLDERID_PublicMusic: str
FOLDERID_PublicVideos: str
FOLDERID_PublicRingtones: str
FOLDERID_ResourceDir: str
FOLDERID_LocalizedResourcesDir: str
FOLDERID_CommonOEMLinks: str
FOLDERID_CDBurning: str
FOLDERID_UserProfiles: str
FOLDERID_Playlists: str
FOLDERID_SamplePlaylists: str
FOLDERID_SampleMusic: str
FOLDERID_SamplePictures: str
FOLDERID_SampleVideos: str
FOLDERID_PhotoAlbums: str
FOLDERID_Public: str
FOLDERID_ChangeRemovePrograms: str
FOLDERID_AppUpdates: str
FOLDERID_AddNewPrograms: str
FOLDERID_Downloads: str
FOLDERID_PublicDownloads: str
FOLDERID_SavedSearches: str
FOLDERID_QuickLaunch: str
FOLDERID_Contacts: str
FOLDERID_SidebarParts: str
FOLDERID_SidebarDefaultParts: str
FOLDERID_PublicGameTasks: str
FOLDERID_GameTasks: str
FOLDERID_SavedGames: str
FOLDERID_Games: str
FOLDERID_SEARCH_MAPI: str
FOLDERID_SEARCH_CSC: str
FOLDERID_Links: str
FOLDERID_UsersFiles: str
FOLDERID_UsersLibraries: str
FOLDERID_SearchHome: str
FOLDERID_OriginalImages: str
FOLDERID_DocumentsLibrary: str
FOLDERID_MusicLibrary: str
FOLDERID_PicturesLibrary: str
FOLDERID_VideosLibrary: str
FOLDERID_RecordedTVLibrary: str
FOLDERID_HomeGroup: str
FOLDERID_HomeGroupCurrentUser: str
FOLDERID_DeviceMetadataStore: str
FOLDERID_Libraries: str
FOLDERID_PublicLibraries: str
FOLDERID_UserPinned: str
FOLDERID_ImplicitAppShortcuts: str
FOLDERID_AccountPictures: str
FOLDERID_PublicUserTiles: str
FOLDERID_AppsFolder: str
FOLDERID_StartMenuAllPrograms: str
FOLDERID_CommonStartMenuPlaces: str
FOLDERID_ApplicationShortcuts: str
FOLDERID_RoamingTiles: str
FOLDERID_RoamedTileImages: str
FOLDERID_Screenshots: str
FOLDERID_CameraRoll: str
FOLDERID_SkyDrive: str
FOLDERID_OneDrive: str
FOLDERID_SkyDriveDocuments: str
FOLDERID_SkyDrivePictures: str
FOLDERID_SkyDriveMusic: str
FOLDERID_SkyDriveCameraRoll: str
FOLDERID_SearchHistory: str
FOLDERID_SearchTemplates: str
FOLDERID_CameraRollLibrary: str
FOLDERID_SavedPictures: str
FOLDERID_SavedPicturesLibrary: str
FOLDERID_RetailDemo: str
FOLDERID_Device: str
FOLDERID_DevelopmentFiles: str
FOLDERID_Objects3D: str
FOLDERID_AppCaptures: str
FOLDERID_LocalDocuments: str
FOLDERID_LocalPictures: str
FOLDERID_LocalVideos: str
FOLDERID_LocalMusic: str
FOLDERID_LocalDownloads: str
FOLDERID_RecordedCalls: str
KF_FLAG_DEFAULT: int
KF_FLAG_FORCE_APP_DATA_REDIRECTION: int
KF_FLAG_RETURN_FILTER_REDIRECTION_TARGET: int
KF_FLAG_FORCE_PACKAGE_REDIRECTION: int
KF_FLAG_NO_PACKAGE_REDIRECTION: int
KF_FLAG_FORCE_APPCONTAINER_REDIRECTION: int
KF_FLAG_NO_APPCONTAINER_REDIRECTION: int
KF_FLAG_ALIAS_ONLY: int



import _win32typing

def OpenThemeData(hwnd: int, pszClasslist: str) -> _win32typing.PyHTHEME: ...
def CloseThemeData(hTheme: _win32typing.PyHTHEME) -> None: ...
def DrawThemeBackground(hTheme: _win32typing.PyHTHEME, hdc, iPartId, iStateId, pRect, pClipRect) -> None: ...
def DrawThemeText(
    hTheme: _win32typing.PyHTHEME, hdc, iPartId, iStateId, pszText: str, dwCharCount, dwTextFlags, dwTextFlags2, pRect
) -> None: ...
def GetThemeBackgroundContentRect(hTheme: _win32typing.PyHTHEME, hdc, iPartId, iStateId, pBoundingRect): ...
def GetThemeBackgroundExtent(hTheme: _win32typing.PyHTHEME, hdc, iPartId, iStateId, pContentRect): ...
def IsThemeActive() -> int: ...
def IsAppThemed() -> int: ...
def GetWindowTheme(hwnd: int) -> _win32typing.PyHTHEME: ...
def EnableThemeDialogTexture(hdlg, dwFlags) -> None: ...
def IsThemeDialogTextureEnabled(__hdlg: int | None) -> bool: ...
def GetThemeAppProperties(): ...
def EnableTheming(fEnable) -> None: ...
def SetWindowTheme(hwnd: int, pszSubAppName: str, pszSubIdlist: str) -> None: ...
def GetCurrentThemeName() -> tuple[str, str, str]: ...

ETDT_DISABLE: int
ETDT_ENABLE: int
ETDT_ENABLETAB: int
ETDT_USETABTEXTURE: int
UNICODE: int



from _typeshed import Incomplete
from typing_extensions import TypeAlias

import _win32typing
from win32.lib.pywintypes import com_error

error: TypeAlias = com_error  # noqa: Y042

def ADsOpenObject(path, username, password, iid: _win32typing.PyIID, reserved: int = ...): ...
def ADsGetObject(path, iid: _win32typing.PyIID): ...
def ADsBuildEnumerator(container: _win32typing.PyIADsContainer): ...
def ADsEnumerateNext(enum, num: int = ...): ...
def ADsGetLastError() -> tuple[Incomplete, Incomplete, Incomplete]: ...
def StringAsDS_SELECTION_LIST(*args, **kwargs): ...  # incomplete

DSOP_SCOPE_INIT_INFOs = _win32typing.PyDSOP_SCOPE_INIT_INFOs
CLSID_ADsDSOObject: _win32typing.PyIID
CLSID_AccessControlEntry: _win32typing.PyIID
CLSID_AccessControlList: _win32typing.PyIID
CLSID_DsObjectPicker: _win32typing.PyIID
CLSID_SecurityDescriptor: _win32typing.PyIID
DBGUID_LDAPDialect: _win32typing.PyIID
DBPROPSET_ADSISEARCH: _win32typing.PyIID
IID_IADs: _win32typing.PyIID
IID_IADsClass: _win32typing.PyIID
IID_IADsCollection: _win32typing.PyIID
IID_IADsComputer: _win32typing.PyIID
IID_IADsComputerOperations: _win32typing.PyIID
IID_IADsContainer: _win32typing.PyIID
IID_IADsDeleteOps: _win32typing.PyIID
IID_IADsDomain: _win32typing.PyIID
IID_IADsFileService: _win32typing.PyIID
IID_IADsFileServiceOperations: _win32typing.PyIID
IID_IADsFileShare: _win32typing.PyIID
IID_IADsGroup: _win32typing.PyIID
IID_IADsLocality: _win32typing.PyIID
IID_IADsMembers: _win32typing.PyIID
IID_IADsNamespaces: _win32typing.PyIID
IID_IADsO: _win32typing.PyIID
IID_IADsOU: _win32typing.PyIID
IID_IADsOpenDSObject: _win32typing.PyIID
IID_IADsPrintJob: _win32typing.PyIID
IID_IADsPrintJobOperations: _win32typing.PyIID
IID_IADsPrintQueue: _win32typing.PyIID
IID_IADsPrintQueueOperations: _win32typing.PyIID
IID_IADsProperty: _win32typing.PyIID
IID_IADsPropertyList: _win32typing.PyIID
IID_IADsResource: _win32typing.PyIID
IID_IADsSearch: _win32typing.PyIID
IID_IADsService: _win32typing.PyIID
IID_IADsServiceOperations: _win32typing.PyIID
IID_IADsSession: _win32typing.PyIID
IID_IADsSyntax: _win32typing.PyIID
IID_IADsUser: _win32typing.PyIID
IID_IDirectoryObject: _win32typing.PyIID
IID_IDirectorySearch: _win32typing.PyIID
IID_IDsObjectPicker: _win32typing.PyIID
LIBID_ADs: _win32typing.PyIID



from _typeshed import Incomplete

WM_USER: int
ICC_LISTVIEW_CLASSES: int
ICC_TREEVIEW_CLASSES: int
ICC_BAR_CLASSES: int
ICC_TAB_CLASSES: int
ICC_UPDOWN_CLASS: int
ICC_PROGRESS_CLASS: int
ICC_HOTKEY_CLASS: int
ICC_ANIMATE_CLASS: int
ICC_WIN95_CLASSES: int
ICC_DATE_CLASSES: int
ICC_USEREX_CLASSES: int
ICC_COOL_CLASSES: int
ICC_INTERNET_CLASSES: int
ICC_PAGESCROLLER_CLASS: int
ICC_NATIVEFNTCTL_CLASS: int
ODT_HEADER: int
ODT_TAB: int
ODT_LISTVIEW: int
PY_0U: int
NM_FIRST: int
NM_LAST: Incomplete
LVN_FIRST: Incomplete
LVN_LAST: Incomplete
HDN_FIRST: Incomplete
HDN_LAST: Incomplete
TVN_FIRST: Incomplete
TVN_LAST: Incomplete
TTN_FIRST: Incomplete
TTN_LAST: Incomplete
TCN_FIRST: Incomplete
TCN_LAST: Incomplete
CDN_FIRST: Incomplete
CDN_LAST: Incomplete
TBN_FIRST: Incomplete
TBN_LAST: Incomplete
UDN_FIRST: Incomplete
UDN_LAST: Incomplete
MCN_FIRST: Incomplete
MCN_LAST: Incomplete
DTN_FIRST: Incomplete
DTN_LAST: Incomplete
CBEN_FIRST: Incomplete
CBEN_LAST: Incomplete
RBN_FIRST: Incomplete
RBN_LAST: Incomplete
IPN_FIRST: Incomplete
IPN_LAST: Incomplete
SBN_FIRST: Incomplete
SBN_LAST: Incomplete
PGN_FIRST: Incomplete
PGN_LAST: Incomplete
LVM_FIRST: int
TV_FIRST: int
HDM_FIRST: int
TCM_FIRST: int
PGM_FIRST: int
CCM_FIRST: int
CCM_SETBKCOLOR: Incomplete
CCM_SETCOLORSCHEME: Incomplete
CCM_GETCOLORSCHEME: Incomplete
CCM_GETDROPTARGET: Incomplete
CCM_SETUNICODEFORMAT: Incomplete
CCM_GETUNICODEFORMAT: Incomplete
INFOTIPSIZE: int
NM_OUTOFMEMORY: Incomplete
NM_CLICK: Incomplete
NM_DBLCLK: Incomplete
NM_RETURN: Incomplete
NM_RCLICK: Incomplete
NM_RDBLCLK: Incomplete
NM_SETFOCUS: Incomplete
NM_KILLFOCUS: Incomplete
NM_CUSTOMDRAW: Incomplete
NM_HOVER: Incomplete
NM_NCHITTEST: Incomplete
NM_KEYDOWN: Incomplete
NM_RELEASEDCAPTURE: Incomplete
NM_SETCURSOR: Incomplete
NM_CHAR: Incomplete
MSGF_COMMCTRL_BEGINDRAG: int
MSGF_COMMCTRL_SIZEHEADER: int
MSGF_COMMCTRL_DRAGSELECT: int
MSGF_COMMCTRL_TOOLBARCUST: int
CDRF_DODEFAULT: int
CDRF_NEWFONT: int
CDRF_SKIPDEFAULT: int
CDRF_NOTIFYPOSTPAINT: int
CDRF_NOTIFYITEMDRAW: int
CDRF_NOTIFYSUBITEMDRAW: int
CDRF_NOTIFYPOSTERASE: int
CDDS_PREPAINT: int
CDDS_POSTPAINT: int
CDDS_PREERASE: int
CDDS_POSTERASE: int
CDDS_ITEM: int
CDDS_ITEMPREPAINT: Incomplete
CDDS_ITEMPOSTPAINT: Incomplete
CDDS_ITEMPREERASE: Incomplete
CDDS_ITEMPOSTERASE: Incomplete
CDDS_SUBITEM: int
CDIS_SELECTED: int
CDIS_GRAYED: int
CDIS_DISABLED: int
CDIS_CHECKED: int
CDIS_FOCUS: int
CDIS_DEFAULT: int
CDIS_HOT: int
CDIS_MARKED: int
CDIS_INDETERMINATE: int
CLR_NONE: int
CLR_DEFAULT: int
ILC_MASK: int
ILC_COLOR: int
ILC_COLORDDB: int
ILC_COLOR4: int
ILC_COLOR8: int
ILC_COLOR16: int
ILC_COLOR24: int
ILC_COLOR32: int
ILC_PALETTE: int
ILD_NORMAL: int
ILD_TRANSPARENT: int
ILD_MASK: int
ILD_IMAGE: int
ILD_ROP: int
ILD_BLEND25: int
ILD_BLEND50: int
ILD_OVERLAYMASK: int
ILD_SELECTED: int
ILD_FOCUS: int
ILD_BLEND: int
CLR_HILIGHT: int
ILCF_MOVE: int
ILCF_SWAP: int
WC_HEADERA: str
WC_HEADER: str
HDS_HORZ: int
HDS_BUTTONS: int
HDS_HOTTRACK: int
HDS_HIDDEN: int
HDS_DRAGDROP: int
HDS_FULLDRAG: int
HDI_WIDTH: int
HDI_HEIGHT: int
HDI_TEXT: int
HDI_FORMAT: int
HDI_LPARAM: int
HDI_BITMAP: int
HDI_IMAGE: int
HDI_DI_SETITEM: int
HDI_ORDER: int
HDF_LEFT: int
HDF_RIGHT: int
HDF_CENTER: int
HDF_JUSTIFYMASK: int
HDF_RTLREADING: int
HDF_OWNERDRAW: int
HDF_STRING: int
HDF_BITMAP: int
HDF_BITMAP_ON_RIGHT: int
HDF_IMAGE: int
HDM_GETITEMCOUNT: Incomplete
HDM_INSERTITEMA: Incomplete
HDM_INSERTITEMW: Incomplete
HDM_INSERTITEM: Incomplete
HDM_DELETEITEM: Incomplete
HDM_GETITEMA: Incomplete
HDM_GETITEMW: Incomplete
HDM_GETITEM: Incomplete
HDM_SETITEMA: Incomplete
HDM_SETITEMW: Incomplete
HDM_SETITEM: Incomplete
HDM_LAYOUT: Incomplete
HHT_NOWHERE: int
HHT_ONHEADER: int
HHT_ONDIVIDER: int
HHT_ONDIVOPEN: int
HHT_ABOVE: int
HHT_BELOW: int
HHT_TORIGHT: int
HHT_TOLEFT: int
HDM_HITTEST: Incomplete
HDM_GETITEMRECT: Incomplete
HDM_SETIMAGELIST: Incomplete
HDM_GETIMAGELIST: Incomplete
HDM_ORDERTOINDEX: Incomplete
HDM_CREATEDRAGIMAGE: Incomplete
HDM_GETORDERARRAY: Incomplete
HDM_SETORDERARRAY: Incomplete
HDM_SETHOTDIVIDER: Incomplete
HDM_SETUNICODEFORMAT: Incomplete
HDM_GETUNICODEFORMAT: Incomplete
HDN_ITEMCHANGINGA: Incomplete
HDN_ITEMCHANGINGW: Incomplete
HDN_ITEMCHANGEDA: Incomplete
HDN_ITEMCHANGEDW: Incomplete
HDN_ITEMCLICKA: Incomplete
HDN_ITEMCLICKW: Incomplete
HDN_ITEMDBLCLICKA: Incomplete
HDN_ITEMDBLCLICKW: Incomplete
HDN_DIVIDERDBLCLICKA: Incomplete
HDN_DIVIDERDBLCLICKW: Incomplete
HDN_BEGINTRACKA: Incomplete
HDN_BEGINTRACKW: Incomplete
HDN_ENDTRACKA: Incomplete
HDN_ENDTRACKW: Incomplete
HDN_TRACKA: Incomplete
HDN_TRACKW: Incomplete
HDN_GETDISPINFOA: Incomplete
HDN_GETDISPINFOW: Incomplete
HDN_BEGINDRAG: Incomplete
HDN_ENDDRAG: Incomplete
HDN_ITEMCHANGING: Incomplete
HDN_ITEMCHANGED: Incomplete
HDN_ITEMCLICK: Incomplete
HDN_ITEMDBLCLICK: Incomplete
HDN_DIVIDERDBLCLICK: Incomplete
HDN_BEGINTRACK: Incomplete
HDN_ENDTRACK: Incomplete
HDN_TRACK: Incomplete
HDN_GETDISPINFO: Incomplete
TOOLBARCLASSNAMEA: str
TOOLBARCLASSNAME: str
CMB_MASKED: int
TBSTATE_CHECKED: int
TBSTATE_PRESSED: int
TBSTATE_ENABLED: int
TBSTATE_HIDDEN: int
TBSTATE_INDETERMINATE: int
TBSTATE_WRAP: int
TBSTATE_ELLIPSES: int
TBSTATE_MARKED: int
TBSTYLE_BUTTON: int
TBSTYLE_SEP: int
TBSTYLE_CHECK: int
TBSTYLE_GROUP: int
TBSTYLE_CHECKGROUP: Incomplete
TBSTYLE_DROPDOWN: int
TBSTYLE_AUTOSIZE: int
TBSTYLE_NOPREFIX: int
TBSTYLE_TOOLTIPS: int
TBSTYLE_WRAPABLE: int
TBSTYLE_ALTDRAG: int
TBSTYLE_FLAT: int
TBSTYLE_LIST: int
TBSTYLE_CUSTOMERASE: int
TBSTYLE_REGISTERDROP: int
TBSTYLE_TRANSPARENT: int
TBSTYLE_EX_DRAWDDARROWS: int
BTNS_BUTTON: int
BTNS_SEP: int
BTNS_CHECK: int
BTNS_GROUP: int
BTNS_CHECKGROUP: Incomplete
BTNS_DROPDOWN: int
BTNS_AUTOSIZE: int
BTNS_NOPREFIX: int
BTNS_SHOWTEXT: int
BTNS_WHOLEDROPDOWN: int
TBCDRF_NOEDGES: int
TBCDRF_HILITEHOTTRACK: int
TBCDRF_NOOFFSET: int
TBCDRF_NOMARK: int
TBCDRF_NOETCHEDEFFECT: int
TB_ENABLEBUTTON: Incomplete
TB_CHECKBUTTON: Incomplete
TB_PRESSBUTTON: Incomplete
TB_HIDEBUTTON: Incomplete
TB_INDETERMINATE: Incomplete
TB_MARKBUTTON: Incomplete
TB_ISBUTTONENABLED: Incomplete
TB_ISBUTTONCHECKED: Incomplete
TB_ISBUTTONPRESSED: Incomplete
TB_ISBUTTONHIDDEN: Incomplete
TB_ISBUTTONINDETERMINATE: Incomplete
TB_ISBUTTONHIGHLIGHTED: Incomplete
TB_SETSTATE: Incomplete
TB_GETSTATE: Incomplete
TB_ADDBITMAP: Incomplete
HINST_COMMCTRL: int
IDB_STD_SMALL_COLOR: int
IDB_STD_LARGE_COLOR: int
IDB_VIEW_SMALL_COLOR: int
IDB_VIEW_LARGE_COLOR: int
IDB_HIST_SMALL_COLOR: int
IDB_HIST_LARGE_COLOR: int
STD_CUT: int
STD_COPY: int
STD_PASTE: int
STD_UNDO: int
STD_REDOW: int
STD_DELETE: int
STD_FILENEW: int
STD_FILEOPEN: int
STD_FILESAVE: int
STD_PRINTPRE: int
STD_PROPERTIES: int
STD_HELP: int
STD_FIND: int
STD_REPLACE: int
STD_PRINT: int
VIEW_LARGEICONS: int
VIEW_SMALLICONS: int
VIEW_LIST: int
VIEW_DETAILS: int
VIEW_SORTNAME: int
VIEW_SORTSIZE: int
VIEW_SORTDATE: int
VIEW_SORTTYPE: int
VIEW_PARENTFOLDER: int
VIEW_NETCONNECT: int
VIEW_NETDISCONNECT: int
VIEW_NEWFOLDER: int
VIEW_VIEWMENU: int
HIST_BACK: int
HIST_FORWARD: int
HIST_FAVORITES: int
HIST_ADDTOFAVORITES: int
HIST_VIEWTREE: int
TB_ADDBUTTONSA: Incomplete
TB_INSERTBUTTONA: Incomplete
TB_ADDBUTTONS: Incomplete
TB_INSERTBUTTON: Incomplete
TB_DELETEBUTTON: Incomplete
TB_GETBUTTON: Incomplete
TB_BUTTONCOUNT: Incomplete
TB_COMMANDTOINDEX: Incomplete
TB_SAVERESTOREA: Incomplete
TB_SAVERESTOREW: Incomplete
TB_CUSTOMIZE: Incomplete
TB_ADDSTRINGA: Incomplete
TB_ADDSTRINGW: Incomplete
TB_GETITEMRECT: Incomplete
TB_BUTTONSTRUCTSIZE: Incomplete
TB_SETBUTTONSIZE: Incomplete
TB_SETBITMAPSIZE: Incomplete
TB_AUTOSIZE: Incomplete
TB_GETTOOLTIPS: Incomplete
TB_SETTOOLTIPS: Incomplete
TB_SETPARENT: Incomplete
TB_SETROWS: Incomplete
TB_GETROWS: Incomplete
TB_SETCMDID: Incomplete
TB_CHANGEBITMAP: Incomplete
TB_GETBITMAP: Incomplete
TB_GETBUTTONTEXTA: Incomplete
TB_GETBUTTONTEXTW: Incomplete
TB_REPLACEBITMAP: Incomplete
TB_SETINDENT: Incomplete
TB_SETIMAGELIST: Incomplete
TB_GETIMAGELIST: Incomplete
TB_LOADIMAGES: Incomplete
TB_GETRECT: Incomplete
TB_SETHOTIMAGELIST: Incomplete
TB_GETHOTIMAGELIST: Incomplete
TB_SETDISABLEDIMAGELIST: Incomplete
TB_GETDISABLEDIMAGELIST: Incomplete
TB_SETSTYLE: Incomplete
TB_GETSTYLE: Incomplete
TB_GETBUTTONSIZE: Incomplete
TB_SETBUTTONWIDTH: Incomplete
TB_SETMAXTEXTROWS: Incomplete
TB_GETTEXTROWS: Incomplete
TB_GETBUTTONTEXT: Incomplete
TB_SAVERESTORE: Incomplete
TB_ADDSTRING: Incomplete
TB_GETOBJECT: Incomplete
TB_GETHOTITEM: Incomplete
TB_SETHOTITEM: Incomplete
TB_SETANCHORHIGHLIGHT: Incomplete
TB_GETANCHORHIGHLIGHT: Incomplete
TB_MAPACCELERATORA: Incomplete
TBIMHT_AFTER: int
TBIMHT_BACKGROUND: int
TB_GETINSERTMARK: Incomplete
TB_SETINSERTMARK: Incomplete
TB_INSERTMARKHITTEST: Incomplete
TB_MOVEBUTTON: Incomplete
TB_GETMAXSIZE: Incomplete
TB_SETEXTENDEDSTYLE: Incomplete
TB_GETEXTENDEDSTYLE: Incomplete
TB_GETPADDING: Incomplete
TB_SETPADDING: Incomplete
TB_SETINSERTMARKCOLOR: Incomplete
TB_GETINSERTMARKCOLOR: Incomplete
TB_SETCOLORSCHEME: Incomplete
TB_GETCOLORSCHEME: Incomplete
TB_SETUNICODEFORMAT: Incomplete
TB_GETUNICODEFORMAT: Incomplete
TB_MAPACCELERATORW: Incomplete
TB_MAPACCELERATOR: Incomplete
TBBF_LARGE: int
TB_GETBITMAPFLAGS: Incomplete
TBIF_IMAGE: int
TBIF_TEXT: int
TBIF_STATE: int
TBIF_STYLE: int
TBIF_LPARAM: int
TBIF_COMMAND: int
TBIF_SIZE: int
TB_GETBUTTONINFOW: Incomplete
TB_SETBUTTONINFOW: Incomplete
TB_GETBUTTONINFOA: Incomplete
TB_SETBUTTONINFOA: Incomplete
TB_INSERTBUTTONW: Incomplete
TB_ADDBUTTONSW: Incomplete
TB_HITTEST: Incomplete
TB_SETDRAWTEXTFLAGS: Incomplete
TBN_GETBUTTONINFOA: Incomplete
TBN_GETBUTTONINFOW: Incomplete
TBN_BEGINDRAG: Incomplete
TBN_ENDDRAG: Incomplete
TBN_BEGINADJUST: Incomplete
TBN_ENDADJUST: Incomplete
TBN_RESET: Incomplete
TBN_QUERYINSERT: Incomplete
TBN_QUERYDELETE: Incomplete
TBN_TOOLBARCHANGE: Incomplete
TBN_CUSTHELP: Incomplete
TBN_DROPDOWN: Incomplete
TBN_GETOBJECT: Incomplete
HICF_OTHER: int
HICF_MOUSE: int
HICF_ARROWKEYS: int
HICF_ACCELERATOR: int
HICF_DUPACCEL: int
HICF_ENTERING: int
HICF_LEAVING: int
HICF_RESELECT: int
TBN_HOTITEMCHANGE: Incomplete
TBN_DRAGOUT: Incomplete
TBN_DELETINGBUTTON: Incomplete
TBN_GETDISPINFOA: Incomplete
TBN_GETDISPINFOW: Incomplete
TBN_GETINFOTIPA: Incomplete
TBN_GETINFOTIPW: Incomplete
TBN_GETINFOTIP: Incomplete
TBNF_IMAGE: int
TBNF_TEXT: int
TBNF_DI_SETITEM: int
TBN_GETDISPINFO: Incomplete
TBDDRET_DEFAULT: int
TBDDRET_NODEFAULT: int
TBDDRET_TREATPRESSED: int
TBN_GETBUTTONINFO: Incomplete
REBARCLASSNAMEA: str
REBARCLASSNAME: str
RBIM_IMAGELIST: int
RBS_TOOLTIPS: int
RBS_VARHEIGHT: int
RBS_BANDBORDERS: int
RBS_FIXEDORDER: int
RBS_REGISTERDROP: int
RBS_AUTOSIZE: int
RBS_VERTICALGRIPPER: int
RBS_DBLCLKTOGGLE: int
RBBS_BREAK: int
RBBS_FIXEDSIZE: int
RBBS_CHILDEDGE: int
RBBS_HIDDEN: int
RBBS_NOVERT: int
RBBS_FIXEDBMP: int
RBBS_VARIABLEHEIGHT: int
RBBS_GRIPPERALWAYS: int
RBBS_NOGRIPPER: int
RBBIM_STYLE: int
RBBIM_COLORS: int
RBBIM_TEXT: int
RBBIM_IMAGE: int
RBBIM_CHILD: int
RBBIM_CHILDSIZE: int
RBBIM_SIZE: int
RBBIM_BACKGROUND: int
RBBIM_ID: int
RBBIM_IDEALSIZE: int
RBBIM_LPARAM: int
RB_INSERTBANDA: Incomplete
RB_DELETEBAND: Incomplete
RB_GETBARINFO: Incomplete
RB_SETBARINFO: Incomplete
RB_SETBANDINFOA: Incomplete
RB_SETPARENT: Incomplete
RB_HITTEST: Incomplete
RB_GETRECT: Incomplete
RB_INSERTBANDW: Incomplete
RB_SETBANDINFOW: Incomplete
RB_GETBANDCOUNT: Incomplete
RB_GETROWCOUNT: Incomplete
RB_GETROWHEIGHT: Incomplete
RB_IDTOINDEX: Incomplete
RB_GETTOOLTIPS: Incomplete
RB_SETTOOLTIPS: Incomplete
RB_SETBKCOLOR: Incomplete
RB_GETBKCOLOR: Incomplete
RB_SETTEXTCOLOR: Incomplete
RB_GETTEXTCOLOR: Incomplete
RB_SIZETORECT: Incomplete
RB_SETCOLORSCHEME: Incomplete
RB_GETCOLORSCHEME: Incomplete
RB_INSERTBAND: Incomplete
RB_SETBANDINFO: Incomplete
RB_BEGINDRAG: Incomplete
RB_ENDDRAG: Incomplete
RB_DRAGMOVE: Incomplete
RB_GETBARHEIGHT: Incomplete
RB_GETBANDINFOW: Incomplete
RB_GETBANDINFOA: Incomplete
RB_GETBANDINFO: Incomplete
RB_MINIMIZEBAND: Incomplete
RB_MAXIMIZEBAND: Incomplete
RB_GETDROPTARGET: Incomplete
RB_GETBANDBORDERS: Incomplete
RB_SHOWBAND: Incomplete
RB_SETPALETTE: Incomplete
RB_GETPALETTE: Incomplete
RB_MOVEBAND: Incomplete
RB_SETUNICODEFORMAT: Incomplete
RB_GETUNICODEFORMAT: Incomplete
RBN_HEIGHTCHANGE: Incomplete
RBN_GETOBJECT: Incomplete
RBN_LAYOUTCHANGED: Incomplete
RBN_AUTOSIZE: Incomplete
RBN_BEGINDRAG: Incomplete
RBN_ENDDRAG: Incomplete
RBN_DELETINGBAND: Incomplete
RBN_DELETEDBAND: Incomplete
RBN_CHILDSIZE: Incomplete
RBNM_ID: int
RBNM_STYLE: int
RBNM_LPARAM: int
RBHT_NOWHERE: int
RBHT_CAPTION: int
RBHT_CLIENT: int
RBHT_GRABBER: int
TOOLTIPS_CLASSA: str
TOOLTIPS_CLASS: str
TTS_ALWAYSTIP: int
TTS_NOPREFIX: int
TTF_IDISHWND: int
TTF_CENTERTIP: int
TTF_RTLREADING: int
TTF_SUBCLASS: int
TTF_TRACK: int
TTF_ABSOLUTE: int
TTF_TRANSPARENT: int
TTF_DI_SETITEM: int
TTDT_AUTOMATIC: int
TTDT_RESHOW: int
TTDT_AUTOPOP: int
TTDT_INITIAL: int
TTM_ACTIVATE: Incomplete
TTM_SETDELAYTIME: Incomplete
TTM_ADDTOOLA: Incomplete
TTM_ADDTOOLW: Incomplete
TTM_DELTOOLA: Incomplete
TTM_DELTOOLW: Incomplete
TTM_NEWTOOLRECTA: Incomplete
TTM_NEWTOOLRECTW: Incomplete
TTM_RELAYEVENT: Incomplete
TTM_GETTOOLINFOA: Incomplete
TTM_GETTOOLINFOW: Incomplete
TTM_SETTOOLINFOA: Incomplete
TTM_SETTOOLINFOW: Incomplete
TTM_HITTESTA: Incomplete
TTM_HITTESTW: Incomplete
TTM_GETTEXTA: Incomplete
TTM_GETTEXTW: Incomplete
TTM_UPDATETIPTEXTA: Incomplete
TTM_UPDATETIPTEXTW: Incomplete
TTM_GETTOOLCOUNT: Incomplete
TTM_ENUMTOOLSA: Incomplete
TTM_ENUMTOOLSW: Incomplete
TTM_GETCURRENTTOOLA: Incomplete
TTM_GETCURRENTTOOLW: Incomplete
TTM_WINDOWFROMPOINT: Incomplete
TTM_TRACKACTIVATE: Incomplete
TTM_TRACKPOSITION: Incomplete
TTM_SETTIPBKCOLOR: Incomplete
TTM_SETTIPTEXTCOLOR: Incomplete
TTM_GETDELAYTIME: Incomplete
TTM_GETTIPBKCOLOR: Incomplete
TTM_GETTIPTEXTCOLOR: Incomplete
TTM_SETMAXTIPWIDTH: Incomplete
TTM_GETMAXTIPWIDTH: Incomplete
TTM_SETMARGIN: Incomplete
TTM_GETMARGIN: Incomplete
TTM_POP: Incomplete
TTM_UPDATE: Incomplete
TTM_ADDTOOL: Incomplete
TTM_DELTOOL: Incomplete
TTM_NEWTOOLRECT: Incomplete
TTM_GETTOOLINFO: Incomplete
TTM_SETTOOLINFO: Incomplete
TTM_HITTEST: Incomplete
TTM_GETTEXT: Incomplete
TTM_UPDATETIPTEXT: Incomplete
TTM_ENUMTOOLS: Incomplete
TTM_GETCURRENTTOOL: Incomplete
TTN_GETDISPINFOA: Incomplete
TTN_GETDISPINFOW: Incomplete
TTN_SHOW: Incomplete
TTN_POP: Incomplete
TTN_GETDISPINFO: Incomplete
TTN_NEEDTEXT: Incomplete
TTN_NEEDTEXTA: Incomplete
TTN_NEEDTEXTW: Incomplete
SBARS_SIZEGRIP: int
SBARS_TOOLTIPS: int
STATUSCLASSNAMEA: str
STATUSCLASSNAME: str
SB_SETTEXTA: Incomplete
SB_SETTEXTW: Incomplete
SB_GETTEXTA: Incomplete
SB_GETTEXTW: Incomplete
SB_GETTEXTLENGTHA: Incomplete
SB_GETTEXTLENGTHW: Incomplete
SB_GETTEXT: Incomplete
SB_SETTEXT: Incomplete
SB_GETTEXTLENGTH: Incomplete
SB_SETPARTS: Incomplete
SB_GETPARTS: Incomplete
SB_GETBORDERS: Incomplete
SB_SETMINHEIGHT: Incomplete
SB_SIMPLE: Incomplete
SB_GETRECT: Incomplete
SB_ISSIMPLE: Incomplete
SB_SETICON: Incomplete
SB_SETTIPTEXTA: Incomplete
SB_SETTIPTEXTW: Incomplete
SB_GETTIPTEXTA: Incomplete
SB_GETTIPTEXTW: Incomplete
SB_GETICON: Incomplete
SB_SETTIPTEXT: Incomplete
SB_GETTIPTEXT: Incomplete
SB_SETUNICODEFORMAT: Incomplete
SB_GETUNICODEFORMAT: Incomplete
SBT_OWNERDRAW: int
SBT_NOBORDERS: int
SBT_POPOUT: int
SBT_RTLREADING: int
SBT_NOTABPARSING: int
SBT_TOOLTIPS: int
SB_SETBKCOLOR: Incomplete
SBN_SIMPLEMODECHANGE: Incomplete
TRACKBAR_CLASSA: str
TRACKBAR_CLASS: str
TBS_AUTOTICKS: int
TBS_VERT: int
TBS_HORZ: int
TBS_TOP: int
TBS_BOTTOM: int
TBS_LEFT: int
TBS_RIGHT: int
TBS_BOTH: int
TBS_NOTICKS: int
TBS_ENABLESELRANGE: int
TBS_FIXEDLENGTH: int
TBS_NOTHUMB: int
TBS_TOOLTIPS: int
TBM_GETPOS: int
TBM_GETRANGEMIN: Incomplete
TBM_GETRANGEMAX: Incomplete
TBM_GETTIC: Incomplete
TBM_SETTIC: Incomplete
TBM_SETPOS: Incomplete
TBM_SETRANGE: Incomplete
TBM_SETRANGEMIN: Incomplete
TBM_SETRANGEMAX: Incomplete
TBM_CLEARTICS: Incomplete
TBM_SETSEL: Incomplete
TBM_SETSELSTART: Incomplete
TBM_SETSELEND: Incomplete
TBM_GETPTICS: Incomplete
TBM_GETTICPOS: Incomplete
TBM_GETNUMTICS: Incomplete
TBM_GETSELSTART: Incomplete
TBM_GETSELEND: Incomplete
TBM_CLEARSEL: Incomplete
TBM_SETTICFREQ: Incomplete
TBM_SETPAGESIZE: Incomplete
TBM_GETPAGESIZE: Incomplete
TBM_SETLINESIZE: Incomplete
TBM_GETLINESIZE: Incomplete
TBM_GETTHUMBRECT: Incomplete
TBM_GETCHANNELRECT: Incomplete
TBM_SETTHUMBLENGTH: Incomplete
TBM_GETTHUMBLENGTH: Incomplete
TBM_SETTOOLTIPS: Incomplete
TBM_GETTOOLTIPS: Incomplete
TBM_SETTIPSIDE: Incomplete
TBTS_TOP: int
TBTS_LEFT: int
TBTS_BOTTOM: int
TBTS_RIGHT: int
TBM_SETBUDDY: Incomplete
TBM_GETBUDDY: Incomplete
TBM_SETUNICODEFORMAT: Incomplete
TBM_GETUNICODEFORMAT: Incomplete
TB_LINEUP: int
TB_LINEDOWN: int
TB_PAGEUP: int
TB_PAGEDOWN: int
TB_THUMBPOSITION: int
TB_THUMBTRACK: int
TB_TOP: int
TB_BOTTOM: int
TB_ENDTRACK: int
TBCD_TICS: int
TBCD_THUMB: int
TBCD_CHANNEL: int
DL_BEGINDRAG: Incomplete
DL_DRAGGING: Incomplete
DL_DROPPED: Incomplete
DL_CANCELDRAG: Incomplete
DL_CURSORSET: int
DL_STOPCURSOR: int
DL_COPYCURSOR: int
DL_MOVECURSOR: int
DRAGLISTMSGSTRING: str
UPDOWN_CLASSA: str
UPDOWN_CLASS: str
UD_MAXVAL: int
UD_MINVAL: Incomplete
UDS_WRAP: int
UDS_SETBUDDYINT: int
UDS_ALIGNRIGHT: int
UDS_ALIGNLEFT: int
UDS_AUTOBUDDY: int
UDS_ARROWKEYS: int
UDS_HORZ: int
UDS_NOTHOUSANDS: int
UDS_HOTTRACK: int
UDM_SETRANGE: Incomplete
UDM_GETRANGE: Incomplete
UDM_SETPOS: Incomplete
UDM_GETPOS: Incomplete
UDM_SETBUDDY: Incomplete
UDM_GETBUDDY: Incomplete
UDM_SETACCEL: Incomplete
UDM_GETACCEL: Incomplete
UDM_SETBASE: Incomplete
UDM_GETBASE: Incomplete
UDM_SETRANGE32: Incomplete
UDM_GETRANGE32: Incomplete
UDM_SETUNICODEFORMAT: Incomplete
UDM_GETUNICODEFORMAT: Incomplete
UDN_DELTAPOS: Incomplete
PROGRESS_CLASSA: str
PROGRESS_CLASS: str
PBS_SMOOTH: int
PBS_VERTICAL: int
PBM_SETRANGE: Incomplete
PBM_SETPOS: Incomplete
PBM_DELTAPOS: Incomplete
PBM_SETSTEP: Incomplete
PBM_STEPIT: Incomplete
PBM_SETRANGE32: Incomplete
PBM_GETRANGE: Incomplete
PBM_GETPOS: Incomplete
PBM_SETBARCOLOR: Incomplete
PBM_SETBKCOLOR: Incomplete
HOTKEYF_SHIFT: int
HOTKEYF_CONTROL: int
HOTKEYF_ALT: int
HOTKEYF_EXT: int
HKCOMB_NONE: int
HKCOMB_S: int
HKCOMB_C: int
HKCOMB_A: int
HKCOMB_SC: int
HKCOMB_SA: int
HKCOMB_CA: int
HKCOMB_SCA: int
HKM_SETHOTKEY: Incomplete
HKM_GETHOTKEY: Incomplete
HKM_SETRULES: Incomplete
HOTKEY_CLASSA: str
HOTKEY_CLASS: str
CCS_TOP: int
CCS_NOMOVEY: int
CCS_BOTTOM: int
CCS_NORESIZE: int
CCS_NOPARENTALIGN: int
CCS_ADJUSTABLE: int
CCS_NODIVIDER: int
CCS_VERT: int
CCS_LEFT: Incomplete
CCS_RIGHT: Incomplete
CCS_NOMOVEX: Incomplete
WC_LISTVIEWA: str
WC_LISTVIEW: str
LVS_ICON: int
LVS_REPORT: int
LVS_SMALLICON: int
LVS_LIST: int
LVS_TYPEMASK: int
LVS_SINGLESEL: int
LVS_SHOWSELALWAYS: int
LVS_SORTASCENDING: int
LVS_SORTDESCENDING: int
LVS_SHAREIMAGELISTS: int
LVS_NOLABELWRAP: int
LVS_AUTOARRANGE: int
LVS_EDITLABELS: int
LVS_OWNERDATA: int
LVS_NOSCROLL: int
LVS_TYPESTYLEMASK: int
LVS_ALIGNTOP: int
LVS_ALIGNLEFT: int
LVS_ALIGNMASK: int
LVS_OWNERDRAWFIXED: int
LVS_NOCOLUMNHEADER: int
LVS_NOSORTHEADER: int
LVM_SETUNICODEFORMAT: Incomplete
LVM_GETUNICODEFORMAT: Incomplete
LVM_GETBKCOLOR: Incomplete
LVM_SETBKCOLOR: Incomplete
LVM_GETIMAGELIST: Incomplete
LVSIL_NORMAL: int
LVSIL_SMALL: int
LVSIL_STATE: int
LVM_SETIMAGELIST: Incomplete
LVM_GETITEMCOUNT: Incomplete
LVIF_TEXT: int
LVIF_IMAGE: int
LVIF_PARAM: int
LVIF_STATE: int
LVIF_INDENT: int
LVIF_NORECOMPUTE: int
LVIS_FOCUSED: int
LVIS_SELECTED: int
LVIS_CUT: int
LVIS_DROPHILITED: int
LVIS_ACTIVATING: int
LVIS_OVERLAYMASK: int
LVIS_STATEIMAGEMASK: int
I_INDENTCALLBACK: int
LPSTR_TEXTCALLBACKA: int
LPSTR_TEXTCALLBACK: int
I_IMAGECALLBACK: int
LVM_GETITEMA: Incomplete
LVM_GETITEMW: Incomplete
LVM_GETITEM: Incomplete
LVM_SETITEMA: Incomplete
LVM_SETITEMW: Incomplete
LVM_SETITEM: Incomplete
LVM_INSERTITEMA: Incomplete
LVM_INSERTITEMW: Incomplete
LVM_INSERTITEM: Incomplete
LVM_DELETEITEM: Incomplete
LVM_DELETEALLITEMS: Incomplete
LVM_GETCALLBACKMASK: Incomplete
LVM_SETCALLBACKMASK: Incomplete
LVNI_ALL: int
LVNI_FOCUSED: int
LVNI_SELECTED: int
LVNI_CUT: int
LVNI_DROPHILITED: int
LVNI_ABOVE: int
LVNI_BELOW: int
LVNI_TOLEFT: int
LVNI_TORIGHT: int
LVM_GETNEXTITEM: Incomplete
LVFI_PARAM: int
LVFI_STRING: int
LVFI_PARTIAL: int
LVFI_WRAP: int
LVFI_NEARESTXY: int
LVM_FINDITEMA: Incomplete
LVM_FINDITEMW: Incomplete
LVM_FINDITEM: Incomplete
LVIR_BOUNDS: int
LVIR_ICON: int
LVIR_LABEL: int
LVIR_SELECTBOUNDS: int
LVM_GETITEMRECT: Incomplete
LVM_SETITEMPOSITION: Incomplete
LVM_GETITEMPOSITION: Incomplete
LVM_GETSTRINGWIDTHA: Incomplete
LVM_GETSTRINGWIDTHW: Incomplete
LVM_GETSTRINGWIDTH: Incomplete
LVHT_NOWHERE: int
LVHT_ONITEMICON: int
LVHT_ONITEMLABEL: int
LVHT_ONITEMSTATEICON: int
LVHT_ONITEM: Incomplete
LVHT_ABOVE: int
LVHT_BELOW: int
LVHT_TORIGHT: int
LVHT_TOLEFT: int
LVM_HITTEST: Incomplete
LVM_ENSUREVISIBLE: Incomplete
LVM_SCROLL: Incomplete
LVM_REDRAWITEMS: Incomplete
LVA_DEFAULT: int
LVA_ALIGNLEFT: int
LVA_ALIGNTOP: int
LVA_SNAPTOGRID: int
LVM_ARRANGE: Incomplete
LVM_EDITLABELA: Incomplete
LVM_EDITLABELW: Incomplete
LVM_EDITLABEL: Incomplete
LVM_GETEDITCONTROL: Incomplete
LVCF_FMT: int
LVCF_WIDTH: int
LVCF_TEXT: int
LVCF_SUBITEM: int
LVCF_IMAGE: int
LVCF_ORDER: int
LVCFMT_LEFT: int
LVCFMT_RIGHT: int
LVCFMT_CENTER: int
LVCFMT_JUSTIFYMASK: int
LVCFMT_IMAGE: int
LVCFMT_BITMAP_ON_RIGHT: int
LVCFMT_COL_HAS_IMAGES: int
LVM_GETCOLUMNA: Incomplete
LVM_GETCOLUMNW: Incomplete
LVM_GETCOLUMN: Incomplete
LVM_SETCOLUMNA: Incomplete
LVM_SETCOLUMNW: Incomplete
LVM_SETCOLUMN: Incomplete
LVM_INSERTCOLUMNA: Incomplete
LVM_INSERTCOLUMNW: Incomplete
LVM_INSERTCOLUMN: Incomplete
LVM_DELETECOLUMN: Incomplete
LVM_GETCOLUMNWIDTH: Incomplete
LVSCW_AUTOSIZE: int
LVSCW_AUTOSIZE_USEHEADER: int
LVM_SETCOLUMNWIDTH: Incomplete
LVM_GETHEADER: Incomplete
LVM_CREATEDRAGIMAGE: Incomplete
LVM_GETVIEWRECT: Incomplete
LVM_GETTEXTCOLOR: Incomplete
LVM_SETTEXTCOLOR: Incomplete
LVM_GETTEXTBKCOLOR: Incomplete
LVM_SETTEXTBKCOLOR: Incomplete
LVM_GETTOPINDEX: Incomplete
LVM_GETCOUNTPERPAGE: Incomplete
LVM_GETORIGIN: Incomplete
LVM_UPDATE: Incomplete
LVM_SETITEMSTATE: Incomplete
LVM_GETITEMSTATE: Incomplete
LVM_GETITEMTEXTA: Incomplete
LVM_GETITEMTEXTW: Incomplete
LVM_GETITEMTEXT: Incomplete
LVM_SETITEMTEXTA: Incomplete
LVM_SETITEMTEXTW: Incomplete
LVM_SETITEMTEXT: Incomplete
LVSICF_NOINVALIDATEALL: int
LVSICF_NOSCROLL: int
LVM_SETITEMCOUNT: Incomplete
LVM_SORTITEMS: Incomplete
LVM_SETITEMPOSITION32: Incomplete
LVM_GETSELECTEDCOUNT: Incomplete
LVM_GETITEMSPACING: Incomplete
LVM_GETISEARCHSTRINGA: Incomplete
LVM_GETISEARCHSTRINGW: Incomplete
LVM_GETISEARCHSTRING: Incomplete
LVM_SETICONSPACING: Incomplete
LVM_SETEXTENDEDLISTVIEWSTYLE: Incomplete
LVM_GETEXTENDEDLISTVIEWSTYLE: Incomplete
LVS_EX_GRIDLINES: int
LVS_EX_SUBITEMIMAGES: int
LVS_EX_CHECKBOXES: int
LVS_EX_TRACKSELECT: int
LVS_EX_HEADERDRAGDROP: int
LVS_EX_FULLROWSELECT: int
LVS_EX_ONECLICKACTIVATE: int
LVS_EX_TWOCLICKACTIVATE: int
LVS_EX_FLATSB: int
LVS_EX_REGIONAL: int
LVS_EX_INFOTIP: int
LVS_EX_UNDERLINEHOT: int
LVS_EX_UNDERLINECOLD: int
LVS_EX_MULTIWORKAREAS: int
LVM_GETSUBITEMRECT: Incomplete
LVM_SUBITEMHITTEST: Incomplete
LVM_SETCOLUMNORDERARRAY: Incomplete
LVM_GETCOLUMNORDERARRAY: Incomplete
LVM_SETHOTITEM: Incomplete
LVM_GETHOTITEM: Incomplete
LVM_SETHOTCURSOR: Incomplete
LVM_GETHOTCURSOR: Incomplete
LVM_APPROXIMATEVIEWRECT: Incomplete
LV_MAX_WORKAREAS: int
LVM_SETWORKAREAS: Incomplete
LVM_GETWORKAREAS: Incomplete
LVM_GETNUMBEROFWORKAREAS: Incomplete
LVM_GETSELECTIONMARK: Incomplete
LVM_SETSELECTIONMARK: Incomplete
LVM_SETHOVERTIME: Incomplete
LVM_GETHOVERTIME: Incomplete
LVM_SETTOOLTIPS: Incomplete
LVM_GETTOOLTIPS: Incomplete
LVBKIF_SOURCE_NONE: int
LVBKIF_SOURCE_HBITMAP: int
LVBKIF_SOURCE_URL: int
LVBKIF_SOURCE_MASK: int
LVBKIF_STYLE_NORMAL: int
LVBKIF_STYLE_TILE: int
LVBKIF_STYLE_MASK: int
LVM_SETBKIMAGEA: Incomplete
LVM_SETBKIMAGEW: Incomplete
LVM_GETBKIMAGEA: Incomplete
LVM_GETBKIMAGEW: Incomplete
LVKF_ALT: int
LVKF_CONTROL: int
LVKF_SHIFT: int
LVN_ITEMCHANGING: Incomplete
LVN_ITEMCHANGED: Incomplete
LVN_INSERTITEM: Incomplete
LVN_DELETEITEM: Incomplete
LVN_DELETEALLITEMS: Incomplete
LVN_BEGINLABELEDITA: Incomplete
LVN_BEGINLABELEDITW: Incomplete
LVN_ENDLABELEDITA: Incomplete
LVN_ENDLABELEDITW: Incomplete
LVN_COLUMNCLICK: Incomplete
LVN_BEGINDRAG: Incomplete
LVN_BEGINRDRAG: Incomplete
LVN_ODCACHEHINT: Incomplete
LVN_ODFINDITEMA: Incomplete
LVN_ODFINDITEMW: Incomplete
LVN_ITEMACTIVATE: Incomplete
LVN_ODSTATECHANGED: Incomplete
LVN_ODFINDITEM: Incomplete
LVN_HOTTRACK: Incomplete
LVN_GETDISPINFOA: Incomplete
LVN_GETDISPINFOW: Incomplete
LVN_SETDISPINFOA: Incomplete
LVN_SETDISPINFOW: Incomplete
LVN_BEGINLABELEDIT: Incomplete
LVN_ENDLABELEDIT: Incomplete
LVN_GETDISPINFO: Incomplete
LVN_SETDISPINFO: Incomplete
LVIF_DI_SETITEM: int
LVN_KEYDOWN: Incomplete
LVN_MARQUEEBEGIN: Incomplete
LVGIT_UNFOLDED: int
LVN_GETINFOTIPA: Incomplete
LVN_GETINFOTIPW: Incomplete
LVN_GETINFOTIP: Incomplete
WC_TREEVIEWA: str
WC_TREEVIEW: str
TVS_HASBUTTONS: int
TVS_HASLINES: int
TVS_LINESATROOT: int
TVS_EDITLABELS: int
TVS_DISABLEDRAGDROP: int
TVS_SHOWSELALWAYS: int
TVS_RTLREADING: int
TVS_NOTOOLTIPS: int
TVS_CHECKBOXES: int
TVS_TRACKSELECT: int
TVS_SINGLEEXPAND: int
TVS_INFOTIP: int
TVS_FULLROWSELECT: int
TVS_NOSCROLL: int
TVS_NONEVENHEIGHT: int
TVIF_TEXT: int
TVIF_IMAGE: int
TVIF_PARAM: int
TVIF_STATE: int
TVIF_HANDLE: int
TVIF_SELECTEDIMAGE: int
TVIF_CHILDREN: int
TVIF_INTEGRAL: int
TVIS_SELECTED: int
TVIS_CUT: int
TVIS_DROPHILITED: int
TVIS_BOLD: int
TVIS_EXPANDED: int
TVIS_EXPANDEDONCE: int
TVIS_EXPANDPARTIAL: int
TVIS_OVERLAYMASK: int
TVIS_STATEIMAGEMASK: int
TVIS_USERMASK: int
I_CHILDRENCALLBACK: int
TVI_ROOT: int
TVI_FIRST: int
TVI_LAST: int
TVI_SORT: int
TVM_INSERTITEMA: Incomplete
TVM_INSERTITEMW: Incomplete
TVM_INSERTITEM: Incomplete
TVM_DELETEITEM: Incomplete
TVM_EXPAND: Incomplete
TVE_COLLAPSE: int
TVE_EXPAND: int
TVE_TOGGLE: int
TVE_EXPANDPARTIAL: int
TVE_COLLAPSERESET: int
TVM_GETITEMRECT: Incomplete
TVM_GETCOUNT: Incomplete
TVM_GETINDENT: Incomplete
TVM_SETINDENT: Incomplete
TVM_GETIMAGELIST: Incomplete
TVSIL_NORMAL: int
TVSIL_STATE: int
TVM_SETIMAGELIST: Incomplete
TVM_GETNEXTITEM: Incomplete
TVGN_ROOT: int
TVGN_NEXT: int
TVGN_PREVIOUS: int
TVGN_PARENT: int
TVGN_CHILD: int
TVGN_FIRSTVISIBLE: int
TVGN_NEXTVISIBLE: int
TVGN_PREVIOUSVISIBLE: int
TVGN_DROPHILITE: int
TVGN_CARET: int
TVGN_LASTVISIBLE: int
TVM_SELECTITEM: Incomplete
TVM_GETITEMA: Incomplete
TVM_GETITEMW: Incomplete
TVM_GETITEM: Incomplete
TVM_SETITEMA: Incomplete
TVM_SETITEMW: Incomplete
TVM_SETITEM: Incomplete
TVM_EDITLABELA: Incomplete
TVM_EDITLABELW: Incomplete
TVM_EDITLABEL: Incomplete
TVM_GETEDITCONTROL: Incomplete
TVM_GETVISIBLECOUNT: Incomplete
TVM_HITTEST: Incomplete
TVHT_NOWHERE: int
TVHT_ONITEMICON: int
TVHT_ONITEMLABEL: int
TVHT_ONITEMINDENT: int
TVHT_ONITEMBUTTON: int
TVHT_ONITEMRIGHT: int
TVHT_ONITEMSTATEICON: int
TVHT_ABOVE: int
TVHT_BELOW: int
TVHT_TORIGHT: int
TVHT_TOLEFT: int
TVHT_ONITEM: Incomplete
TVM_CREATEDRAGIMAGE: Incomplete
TVM_SORTCHILDREN: Incomplete
TVM_ENSUREVISIBLE: Incomplete
TVM_SORTCHILDRENCB: Incomplete
TVM_ENDEDITLABELNOW: Incomplete
TVM_GETISEARCHSTRINGA: Incomplete
TVM_GETISEARCHSTRINGW: Incomplete
TVM_GETISEARCHSTRING: Incomplete
TVM_SETTOOLTIPS: Incomplete
TVM_GETTOOLTIPS: Incomplete
TVM_SETINSERTMARK: Incomplete
TVM_SETUNICODEFORMAT: Incomplete
TVM_GETUNICODEFORMAT: Incomplete
TVM_SETITEMHEIGHT: Incomplete
TVM_GETITEMHEIGHT: Incomplete
TVM_SETBKCOLOR: Incomplete
TVM_SETTEXTCOLOR: Incomplete
TVM_GETBKCOLOR: Incomplete
TVM_GETTEXTCOLOR: Incomplete
TVM_SETSCROLLTIME: Incomplete
TVM_GETSCROLLTIME: Incomplete
TVM_SETINSERTMARKCOLOR: Incomplete
TVM_GETINSERTMARKCOLOR: Incomplete
TVN_SELCHANGINGA: Incomplete
TVN_SELCHANGINGW: Incomplete
TVN_SELCHANGEDA: Incomplete
TVN_SELCHANGEDW: Incomplete
TVC_UNKNOWN: int
TVC_BYMOUSE: int
TVC_BYKEYBOARD: int
TVN_GETDISPINFOA: Incomplete
TVN_GETDISPINFOW: Incomplete
TVN_SETDISPINFOA: Incomplete
TVN_SETDISPINFOW: Incomplete
TVIF_DI_SETITEM: int
TVN_ITEMEXPANDINGA: Incomplete
TVN_ITEMEXPANDINGW: Incomplete
TVN_ITEMEXPANDEDA: Incomplete
TVN_ITEMEXPANDEDW: Incomplete
TVN_BEGINDRAGA: Incomplete
TVN_BEGINDRAGW: Incomplete
TVN_BEGINRDRAGA: Incomplete
TVN_BEGINRDRAGW: Incomplete
TVN_DELETEITEMA: Incomplete
TVN_DELETEITEMW: Incomplete
TVN_BEGINLABELEDITA: Incomplete
TVN_BEGINLABELEDITW: Incomplete
TVN_ENDLABELEDITA: Incomplete
TVN_ENDLABELEDITW: Incomplete
TVN_KEYDOWN: Incomplete
TVN_GETINFOTIPA: Incomplete
TVN_GETINFOTIPW: Incomplete
TVN_SINGLEEXPAND: Incomplete
TVN_SELCHANGING: Incomplete
TVN_SELCHANGED: Incomplete
TVN_GETDISPINFO: Incomplete
TVN_SETDISPINFO: Incomplete
TVN_ITEMEXPANDING: Incomplete
TVN_ITEMEXPANDED: Incomplete
TVN_BEGINDRAG: Incomplete
TVN_BEGINRDRAG: Incomplete
TVN_DELETEITEM: Incomplete
TVN_BEGINLABELEDIT: Incomplete
TVN_ENDLABELEDIT: Incomplete
TVN_GETINFOTIP: Incomplete
TVCDRF_NOIMAGES: int
WC_COMBOBOXEXA: str
WC_COMBOBOXEX: str
CBEIF_TEXT: int
CBEIF_IMAGE: int
CBEIF_SELECTEDIMAGE: int
CBEIF_OVERLAY: int
CBEIF_INDENT: int
CBEIF_LPARAM: int
CBEIF_DI_SETITEM: int
CBEM_INSERTITEMA: Incomplete
CBEM_SETIMAGELIST: Incomplete
CBEM_GETIMAGELIST: Incomplete
CBEM_GETITEMA: Incomplete
CBEM_SETITEMA: Incomplete
CBEM_GETCOMBOCONTROL: Incomplete
CBEM_GETEDITCONTROL: Incomplete
CBEM_SETEXSTYLE: Incomplete
CBEM_SETEXTENDEDSTYLE: Incomplete
CBEM_GETEXSTYLE: Incomplete
CBEM_GETEXTENDEDSTYLE: Incomplete
CBEM_SETUNICODEFORMAT: Incomplete
CBEM_GETUNICODEFORMAT: Incomplete
CBEM_HASEDITCHANGED: Incomplete
CBEM_INSERTITEMW: Incomplete
CBEM_SETITEMW: Incomplete
CBEM_GETITEMW: Incomplete
CBEM_INSERTITEM: Incomplete
CBEM_SETITEM: Incomplete
CBEM_GETITEM: Incomplete
CBES_EX_NOEDITIMAGE: int
CBES_EX_NOEDITIMAGEINDENT: int
CBES_EX_PATHWORDBREAKPROC: int
CBES_EX_NOSIZELIMIT: int
CBES_EX_CASESENSITIVE: int
CBEN_GETDISPINFO: Incomplete
CBEN_GETDISPINFOA: Incomplete
CBEN_INSERTITEM: Incomplete
CBEN_DELETEITEM: Incomplete
CBEN_BEGINEDIT: Incomplete
CBEN_ENDEDITA: Incomplete
CBEN_ENDEDITW: Incomplete
CBEN_GETDISPINFOW: Incomplete
CBEN_DRAGBEGINA: Incomplete
CBEN_DRAGBEGINW: Incomplete
CBEN_DRAGBEGIN: Incomplete
CBEN_ENDEDIT: Incomplete
CBENF_KILLFOCUS: int
CBENF_RETURN: int
CBENF_ESCAPE: int
CBENF_DROPDOWN: int
CBEMAXSTRLEN: int
WC_TABCONTROLA: str
WC_TABCONTROL: str
TCS_SCROLLOPPOSITE: int
TCS_BOTTOM: int
TCS_RIGHT: int
TCS_MULTISELECT: int
TCS_FLATBUTTONS: int
TCS_FORCEICONLEFT: int
TCS_FORCELABELLEFT: int
TCS_HOTTRACK: int
TCS_VERTICAL: int
TCS_TABS: int
TCS_BUTTONS: int
TCS_SINGLELINE: int
TCS_MULTILINE: int
TCS_RIGHTJUSTIFY: int
TCS_FIXEDWIDTH: int
TCS_RAGGEDRIGHT: int
TCS_FOCUSONBUTTONDOWN: int
TCS_OWNERDRAWFIXED: int
TCS_TOOLTIPS: int
TCS_FOCUSNEVER: int
TCS_EX_FLATSEPARATORS: int
TCS_EX_REGISTERDROP: int
TCM_GETIMAGELIST: Incomplete
TCM_SETIMAGELIST: Incomplete
TCM_GETITEMCOUNT: Incomplete
TCIF_TEXT: int
TCIF_IMAGE: int
TCIF_RTLREADING: int
TCIF_PARAM: int
TCIF_STATE: int
TCIS_BUTTONPRESSED: int
TCIS_HIGHLIGHTED: int
TCM_GETITEMA: Incomplete
TCM_GETITEMW: Incomplete
TCM_GETITEM: Incomplete
TCM_SETITEMA: Incomplete
TCM_SETITEMW: Incomplete
TCM_SETITEM: Incomplete
TCM_INSERTITEMA: Incomplete
TCM_INSERTITEMW: Incomplete
TCM_INSERTITEM: Incomplete
TCM_DELETEITEM: Incomplete
TCM_DELETEALLITEMS: Incomplete
TCM_GETITEMRECT: Incomplete
TCM_GETCURSEL: Incomplete
TCM_SETCURSEL: Incomplete
TCHT_NOWHERE: int
TCHT_ONITEMICON: int
TCHT_ONITEMLABEL: int
TCHT_ONITEM: Incomplete
TCM_HITTEST: Incomplete
TCM_SETITEMEXTRA: Incomplete
TCM_ADJUSTRECT: Incomplete
TCM_SETITEMSIZE: Incomplete
TCM_REMOVEIMAGE: Incomplete
TCM_SETPADDING: Incomplete
TCM_GETROWCOUNT: Incomplete
TCM_GETTOOLTIPS: Incomplete
TCM_SETTOOLTIPS: Incomplete
TCM_GETCURFOCUS: Incomplete
TCM_SETCURFOCUS: Incomplete
TCM_SETMINTABWIDTH: Incomplete
TCM_DESELECTALL: Incomplete
TCM_HIGHLIGHTITEM: Incomplete
TCM_SETEXTENDEDSTYLE: Incomplete
TCM_GETEXTENDEDSTYLE: Incomplete
TCM_SETUNICODEFORMAT: Incomplete
TCM_GETUNICODEFORMAT: Incomplete
TCN_KEYDOWN: Incomplete
ANIMATE_CLASSA: str
ANIMATE_CLASS: str
ACS_CENTER: int
ACS_TRANSPARENT: int
ACS_AUTOPLAY: int
ACS_TIMER: int
ACM_OPENA: Incomplete
ACM_OPENW: Incomplete
ACM_OPEN: Incomplete
ACM_PLAY: Incomplete
ACM_STOP: Incomplete
ACN_START: int
ACN_STOP: int
MONTHCAL_CLASSA: str
MONTHCAL_CLASS: str
MCM_FIRST: int
MCM_GETCURSEL: Incomplete
MCM_SETCURSEL: Incomplete
MCM_GETMAXSELCOUNT: Incomplete
MCM_SETMAXSELCOUNT: Incomplete
MCM_GETSELRANGE: Incomplete
MCM_SETSELRANGE: Incomplete
MCM_GETMONTHRANGE: Incomplete
MCM_SETDAYSTATE: Incomplete
MCM_GETMINREQRECT: Incomplete
MCM_SETCOLOR: Incomplete
MCM_GETCOLOR: Incomplete
MCSC_BACKGROUND: int
MCSC_TEXT: int
MCSC_TITLEBK: int
MCSC_TITLETEXT: int
MCSC_MONTHBK: int
MCSC_TRAILINGTEXT: int
MCM_SETTODAY: Incomplete
MCM_GETTODAY: Incomplete
MCM_HITTEST: Incomplete
MCHT_TITLE: int
MCHT_CALENDAR: int
MCHT_TODAYLINK: int
MCHT_NEXT: int
MCHT_PREV: int
MCHT_NOWHERE: int
MCHT_TITLEBK: int
MCHT_TITLEMONTH: Incomplete
MCHT_TITLEYEAR: Incomplete
MCHT_TITLEBTNNEXT: Incomplete
MCHT_TITLEBTNPREV: Incomplete
MCHT_CALENDARBK: int
MCHT_CALENDARDATE: Incomplete
MCHT_CALENDARDATENEXT: Incomplete
MCHT_CALENDARDATEPREV: Incomplete
MCHT_CALENDARDAY: Incomplete
MCHT_CALENDARWEEKNUM: Incomplete
MCM_SETFIRSTDAYOFWEEK: Incomplete
MCM_GETFIRSTDAYOFWEEK: Incomplete
MCM_GETRANGE: Incomplete
MCM_SETRANGE: Incomplete
MCM_GETMONTHDELTA: Incomplete
MCM_SETMONTHDELTA: Incomplete
MCM_GETMAXTODAYWIDTH: Incomplete
MCM_SETUNICODEFORMAT: Incomplete
MCM_GETUNICODEFORMAT: Incomplete
MCN_SELCHANGE: Incomplete
MCN_GETDAYSTATE: Incomplete
MCN_SELECT: Incomplete
MCS_DAYSTATE: int
MCS_MULTISELECT: int
MCS_WEEKNUMBERS: int
MCS_NOTODAYCIRCLE: int
MCS_NOTODAY: int
GMR_VISIBLE: int
GMR_DAYSTATE: int
DATETIMEPICK_CLASSA: str
DATETIMEPICK_CLASS: str
DTM_FIRST: int
DTM_GETSYSTEMTIME: Incomplete
DTM_SETSYSTEMTIME: Incomplete
DTM_GETRANGE: Incomplete
DTM_SETRANGE: Incomplete
DTM_SETFORMATA: Incomplete
DTM_SETFORMATW: Incomplete
DTM_SETFORMAT: Incomplete
DTM_SETMCCOLOR: Incomplete
DTM_GETMCCOLOR: Incomplete
DTM_GETMONTHCAL: Incomplete
DTM_SETMCFONT: Incomplete
DTM_GETMCFONT: Incomplete
DTS_UPDOWN: int
DTS_SHOWNONE: int
DTS_SHORTDATEFORMAT: int
DTS_LONGDATEFORMAT: int
DTS_TIMEFORMAT: int
DTS_APPCANPARSE: int
DTS_RIGHTALIGN: int
DTN_DATETIMECHANGE: Incomplete
DTN_USERSTRINGA: Incomplete
DTN_USERSTRINGW: Incomplete
DTN_USERSTRING: Incomplete
DTN_WMKEYDOWNA: Incomplete
DTN_WMKEYDOWNW: Incomplete
DTN_WMKEYDOWN: Incomplete
DTN_FORMATA: Incomplete
DTN_FORMATW: Incomplete
DTN_FORMAT: Incomplete
DTN_FORMATQUERYA: Incomplete
DTN_FORMATQUERYW: Incomplete
DTN_FORMATQUERY: Incomplete
DTN_DROPDOWN: Incomplete
DTN_CLOSEUP: Incomplete
GDTR_MIN: int
GDTR_MAX: int
GDT_ERROR: int
GDT_VALID: int
GDT_NONE: int
IPM_CLEARADDRESS: Incomplete
IPM_SETADDRESS: Incomplete
IPM_GETADDRESS: Incomplete
IPM_SETRANGE: Incomplete
IPM_SETFOCUS: Incomplete
IPM_ISBLANK: Incomplete
WC_IPADDRESSA: str
WC_IPADDRESS: str
IPN_FIELDCHANGED: Incomplete
WC_PAGESCROLLERA: str
WC_PAGESCROLLER: str
PGS_VERT: int
PGS_HORZ: int
PGS_AUTOSCROLL: int
PGS_DRAGNDROP: int
PGF_INVISIBLE: int
PGF_NORMAL: int
PGF_GRAYED: int
PGF_DEPRESSED: int
PGF_HOT: int
PGB_TOPORLEFT: int
PGB_BOTTOMORRIGHT: int
PGM_SETCHILD: Incomplete
PGM_RECALCSIZE: Incomplete
PGM_FORWARDMOUSE: Incomplete
PGM_SETBKCOLOR: Incomplete
PGM_GETBKCOLOR: Incomplete
PGM_SETBORDER: Incomplete
PGM_GETBORDER: Incomplete
PGM_SETPOS: Incomplete
PGM_GETPOS: Incomplete
PGM_SETBUTTONSIZE: Incomplete
PGM_GETBUTTONSIZE: Incomplete
PGM_GETBUTTONSTATE: Incomplete
PGM_GETDROPTARGET: Incomplete
PGN_SCROLL: Incomplete
PGF_SCROLLUP: int
PGF_SCROLLDOWN: int
PGF_SCROLLLEFT: int
PGF_SCROLLRIGHT: int
PGK_SHIFT: int
PGK_CONTROL: int
PGK_MENU: int
PGN_CALCSIZE: Incomplete
PGF_CALCWIDTH: int
PGF_CALCHEIGHT: int
WC_NATIVEFONTCTLA: str
WC_NATIVEFONTCTL: str
NFS_EDIT: int
NFS_STATIC: int
NFS_LISTCOMBO: int
NFS_BUTTON: int
NFS_ALL: int
WM_MOUSEHOVER: int
WM_MOUSELEAVE: int
TME_HOVER: int
TME_LEAVE: int
TME_QUERY: int
TME_CANCEL: int
HOVER_DEFAULT: int
WSB_PROP_CYVSCROLL: int
WSB_PROP_CXHSCROLL: int
WSB_PROP_CYHSCROLL: int
WSB_PROP_CXVSCROLL: int
WSB_PROP_CXHTHUMB: int
WSB_PROP_CYVTHUMB: int
WSB_PROP_VBKGCOLOR: int
WSB_PROP_HBKGCOLOR: int
WSB_PROP_VSTYLE: int
WSB_PROP_HSTYLE: int
WSB_PROP_WINSTYLE: int
WSB_PROP_PALETTE: int
WSB_PROP_MASK: int
FSB_FLAT_MODE: int
FSB_ENCARTA_MODE: int
FSB_REGULAR_MODE: int

def INDEXTOOVERLAYMASK(i): ...
def INDEXTOSTATEIMAGEMASK(i): ...



import _win32typing

def LoadPerfCounterTextStrings(__commandLine: str) -> None: ...
def UnloadPerfCounterTextStrings(__commandLine: str) -> None: ...
def CounterDefinition() -> _win32typing.PyPERF_COUNTER_DEFINITION: ...
def ObjectType() -> _win32typing.PyPERF_OBJECT_TYPE: ...
def PerfMonManager(
    serviceName: str,
    seqPerfObTypes: list[_win32typing.PyPERF_OBJECT_TYPE],
    mappingName: str | None = ...,
    eventSourceName: str | None = ...,
) -> _win32typing.PyPerfMonManager: ...
